from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class DocxOptions(SpireObject):
    """
    Class representing options for converting a PDF document to a DOCX document.
    """

    @property
    def Title(self) -> str:
        """
        Get the title of the document.
        """
        GetDllLibPdf().DocxOptions_get_Title.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Title.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Title(self.Ptr))
        return ret

    @Title.setter
    def Title(self, value: str):
        """
        Set the title of the document.
        """
        GetDllLibPdf().DocxOptions_set_Title.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Title(self.Ptr, value)

    @property
    def Subject(self) -> str:
        """
        Get the subject of the document.
        """
        GetDllLibPdf().DocxOptions_get_Subject.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Subject.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Subject(self.Ptr))
        return ret

    @Subject.setter
    def Subject(self, value: str):
        """
        Set the subject of the document.
        """
        GetDllLibPdf().DocxOptions_set_Subject.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Subject(self.Ptr, value)

    @property
    def Tags(self) -> str:
        """
        Get the tags of the document.
        """
        GetDllLibPdf().DocxOptions_get_Tags.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Tags.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Tags(self.Ptr))
        return ret

    @Tags.setter
    def Tags(self, value: str):
        """
        Set the tags of the document.
        """
        GetDllLibPdf().DocxOptions_set_Tags.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Tags(self.Ptr, value)

    @property
    def Categories(self) -> str:
        """
        Get the categories of the document.
        """
        GetDllLibPdf().DocxOptions_get_Categories.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Categories.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Categories(self.Ptr))
        return ret

    @Categories.setter
    def Categories(self, value: str):
        """
        Set the categories of the document.
        """
        GetDllLibPdf().DocxOptions_set_Categories.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Categories(self.Ptr, value)

    @property
    def Commments(self) -> str:
        """
        Get the comments of the document.
        """
        GetDllLibPdf().DocxOptions_get_Commments.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Commments.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Commments(self.Ptr))
        return ret

    @Commments.setter
    def Commments(self, value: str):
        """
        Set the comments of the document.
        """
        GetDllLibPdf().DocxOptions_set_Commments.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Commments(self.Ptr, value)

    @property
    def Authors(self) -> str:
        """
        Get the authors of the document.
        """
        GetDllLibPdf().DocxOptions_get_Authors.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Authors.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Authors(self.Ptr))
        return ret

    @Authors.setter
    def Authors(self, value: str):
        """
        Set the authors of the document.
        """
        GetDllLibPdf().DocxOptions_set_Authors.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Authors(self.Ptr, value)

    @property
    def LastSavedBy(self) -> str:
        """
        Get the last saved by information of the document.
        """
        GetDllLibPdf().DocxOptions_get_LastSavedBy.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_LastSavedBy.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_LastSavedBy(self.Ptr))
        return ret

    @LastSavedBy.setter
    def LastSavedBy(self, value: str):
        """
        Set the last saved by information of the document.
        """
        GetDllLibPdf().DocxOptions_set_LastSavedBy.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_LastSavedBy(self.Ptr, value)

    @property
    def Revision(self) -> int:
        """
        Get the revision number of the document.
        """
        GetDllLibPdf().DocxOptions_get_Revision.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Revision.restype = c_int
        ret = GetDllLibPdf().DocxOptions_get_Revision(self.Ptr)
        return ret

    @Revision.setter
    def Revision(self, value: int):
        """
        Set the revision number of the document.
        """
        GetDllLibPdf().DocxOptions_set_Revision.argtypes = [c_void_p, c_int]
        GetDllLibPdf().DocxOptions_set_Revision(self.Ptr, value)

    @property
    def Version(self) -> str:
        """
        Get the version of the document.
        """
        GetDllLibPdf().DocxOptions_get_Version.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Version.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Version(self.Ptr))
        return ret

    @Version.setter
    def Version(self, value: str):
        """
        Set the version of the document.
        """
        GetDllLibPdf().DocxOptions_set_Version.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Version(self.Ptr, value)

    @property
    def ProgramName(self) -> str:
        """
        Get the program name of the document.
        """
        GetDllLibPdf().DocxOptions_get_ProgramName.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_ProgramName.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_ProgramName(self.Ptr))
        return ret

    @ProgramName.setter
    def ProgramName(self, value: str):
        """
        Set the program name of the document.
        """
        GetDllLibPdf().DocxOptions_set_ProgramName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_ProgramName(self.Ptr, value)

    @property
    def Company(self) -> str:
        """
        Get the company of the document.
        """
        GetDllLibPdf().DocxOptions_get_Company.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Company.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Company(self.Ptr))
        return ret

    @Company.setter
    def Company(self, value: str):
        """
        Set the company of the document.
        """
        GetDllLibPdf().DocxOptions_set_Company.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Company(self.Ptr, value)

    @property
    def Manager(self) -> str:
        """
        Get the manager of the document.
        """
        GetDllLibPdf().DocxOptions_get_Manager.argtypes = [c_void_p]
        GetDllLibPdf().DocxOptions_get_Manager.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().DocxOptions_get_Manager(self.Ptr))
        return ret

    @Manager.setter
    def Manager(self, value: str):
        """
        Set the manager of the document.
        """
        GetDllLibPdf().DocxOptions_set_Manager.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().DocxOptions_set_Manager(self.Ptr, value)