from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class LineBorder(SpireObject):
    """
    Represents the border style of the Line annotation.
    """

    @property
    def BorderWidth(self) -> int:
        """
        Gets or sets the width.
        :return: The line border width.
        """
        GetDllLibPdf().LineBorder_get_BorderWidth.argtypes = [c_void_p]
        GetDllLibPdf().LineBorder_get_BorderWidth.restype = c_int
        ret = GetDllLibPdf().LineBorder_get_BorderWidth(self.Ptr)
        return ret

    @BorderWidth.setter
    def BorderWidth(self, value: int):
        """
        Sets the width.
        :param value: The line border width.
        """
        GetDllLibPdf().LineBorder_set_BorderWidth.argtypes = [c_void_p, c_int]
        GetDllLibPdf().LineBorder_set_BorderWidth(self.Ptr, value)

    @property
    def BorderStyle(self) -> 'PdfBorderStyle':
        """
        Gets or sets the border style.
        :return: The line border style.
        """
        GetDllLibPdf().LineBorder_get_BorderStyle.argtypes = [c_void_p]
        GetDllLibPdf().LineBorder_get_BorderStyle.restype = c_int
        ret = GetDllLibPdf().LineBorder_get_BorderStyle(self.Ptr)
        objwrapped = PdfBorderStyle(ret)
        return objwrapped

    @BorderStyle.setter
    def BorderStyle(self, value: 'PdfBorderStyle'):
        """
        Sets the border style.
        :param value: The line border style.
        """
        GetDllLibPdf().LineBorder_set_BorderStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().LineBorder_set_BorderStyle(self.Ptr, value.value)

    @property
    def DashArray(self) -> int:
        """
        Gets or sets the Line Dash.
        :return: The line border dash array.
        """
        GetDllLibPdf().LineBorder_get_DashArray.argtypes = [c_void_p]
        GetDllLibPdf().LineBorder_get_DashArray.restype = c_int
        ret = GetDllLibPdf().LineBorder_get_DashArray(self.Ptr)
        return ret

    @DashArray.setter
    def DashArray(self, value: int):
        """
        Sets the Line Dash.
        :param value: The line border dash array.
        """
        GetDllLibPdf().LineBorder_set_DashArray.argtypes = [c_void_p, c_int]
        GetDllLibPdf().LineBorder_set_DashArray(self.Ptr, value)