from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class Pdf3DCrossSectionCollection(SpireObject):
    """
    Represents the collection of objects.
    """

    def Add(self, value: 'Pdf3DCrossSection') -> int:
        """
        Adds the specified value.

        Args:
            value: The value to add.

        Returns:
            The result of the addition.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DCrossSectionCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DCrossSectionCollection_Add.restype = c_int
        ret = GetDllLibPdf().Pdf3DCrossSectionCollection_Add(self.Ptr, intPtrvalue)
        return ret

    def Contains(self, value: 'Pdf3DCrossSection') -> bool:
        """
        Determines whether the collection contains the specified value.

        Args:
            value: The value to check.

        Returns:
            True if the collection contains the specified value, False otherwise.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DCrossSectionCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DCrossSectionCollection_Contains.restype = c_bool
        ret = GetDllLibPdf().Pdf3DCrossSectionCollection_Contains(self.Ptr, intPtrvalue)
        return ret

    def IndexOf(self, value: 'Pdf3DCrossSection') -> int:
        """
        Returns the index of the specified value in the collection.

        Args:
            value: The value to find.

        Returns:
            The index of the specified value.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DCrossSectionCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DCrossSectionCollection_IndexOf.restype = c_int
        ret = GetDllLibPdf().Pdf3DCrossSectionCollection_IndexOf(self.Ptr, intPtrvalue)
        return ret

    def Insert(self, index: int, value: 'Pdf3DCrossSection'):
        """
        Inserts the specified value at the specified index.

        Args:
            index: The index at which to insert the value.
            value: The value to insert.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DCrossSectionCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().Pdf3DCrossSectionCollection_Insert(self.Ptr, index, intPtrvalue)

    def Remove(self, value: 'Pdf3DCrossSection'):
        """
        Removes the specified value from the collection.

        Args:
            value: The value to remove.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DCrossSectionCollection_Remove.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().Pdf3DCrossSectionCollection_Remove(self.Ptr, intPtrvalue)

    def get_Item(self, index: int) -> 'Pdf3DCrossSection':
        """
        Gets the value at the specified index.

        Args:
            index: The index of the value to get.

        Returns:
            The value at the specified index.
        """
        GetDllLibPdf().Pdf3DCrossSectionCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().Pdf3DCrossSectionCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().Pdf3DCrossSectionCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else Pdf3DCrossSection(intPtr)
        return ret

    def set_Item(self, index: int, value: 'Pdf3DCrossSection'):
        """
        Sets the value at the specified index.

        Args:
            index: The index at which to set the value.
            value: The value to set.
        """
        intPtrvalue: c_void_p = value.Ptr

        GetDllLibPdf().Pdf3DCrossSectionCollection_set_Item.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().Pdf3DCrossSectionCollection_set_Item(self.Ptr, index, intPtrvalue)