from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAnnotation(SpireObject):
    """
    Represents the base class for annotation objects.
    """

    @property
    def Color(self) -> 'PdfRGBColor':
        """
        Gets or sets the background of the annotations icon when closed.
        The title bar of the annotations pop-up window.
        The border of a link annotation.
        """
        GetDllLibPdf().PdfAnnotation_get_Color.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Color.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotation_get_Color(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @Color.setter
    def Color(self, value: 'PdfRGBColor'):
        GetDllLibPdf().PdfAnnotation_set_Color.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotation_set_Color(self.Ptr, value.Ptr)

    @property
    def ModifiedDate(self) -> 'DateTime':
        """
        Gets annotation's modified date.
        """
        GetDllLibPdf().PdfAnnotation_get_ModifiedDate.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_ModifiedDate.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotation_get_ModifiedDate(self.Ptr)
        ret = None if intPtr == None else DateTime(intPtr)
        return ret

    @ModifiedDate.setter
    def ModifiedDate(self, value: 'DateTime'):
        GetDllLibPdf().PdfAnnotation_set_ModifiedDate.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotation_set_ModifiedDate(self.Ptr, value.Ptr)

    @property
    def Border(self) -> 'PdfAnnotationBorder':
        """
        Gets or sets annotation's border.
        """
        GetDllLibPdf().PdfAnnotation_get_Border.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Border.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotation_get_Border(self.Ptr)
        ret = None if intPtr == None else PdfAnnotationBorder(intPtr)
        return ret

    @Border.setter
    def Border(self, value: 'PdfAnnotationBorder'):
        GetDllLibPdf().PdfAnnotation_set_Border.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotation_set_Border(self.Ptr, value.Ptr)

    @property
    def Rectangle(self) -> 'RectangleF':
        """
        Gets or sets the rectangle of the annotation.
        """
        GetDllLibPdf().PdfAnnotation_get_Rectangle.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Rectangle.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotation_get_Rectangle(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @Rectangle.setter
    def Rectangle(self, value: 'RectangleF'):
        GetDllLibPdf().PdfAnnotation_set_Rectangle.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotation_set_Rectangle(self.Ptr, value.Ptr)

    @property
    def Location(self) -> 'PointF':
        """
        Gets or sets the location of the annotation.
        """
        GetDllLibPdf().PdfAnnotation_get_Location.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Location.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotation_get_Location(self.Ptr)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @Location.setter
    def Location(self, value: 'PointF'):
        GetDllLibPdf().PdfAnnotation_set_Location.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotation_set_Location(self.Ptr, value.Ptr)

    @property
    def Name(self) -> str:
        """
        Gets or sets the name of the annotation.
        Note: The annotation name, a text string uniquely identifying it among all the annotations on its page.
        """
        GetDllLibPdf().PdfAnnotation_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Name.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfAnnotation_get_Name(self.Ptr))
        return ret

    @Name.setter
    def Name(self, value: str):
        GetDllLibPdf().PdfAnnotation_set_Name.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfAnnotation_set_Name(self.Ptr, value)

    @property
    def Size(self) -> 'SizeF':
        """
        Gets or sets the size of the annotation.
        """
        GetDllLibPdf().PdfAnnotation_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Size.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAnnotation_get_Size(self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @Size.setter
    def Size(self, value: 'SizeF'):
        GetDllLibPdf().PdfAnnotation_set_Size.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAnnotation_set_Size(self.Ptr, value.Ptr)

    @property
    def Text(self) -> str:
        """
        Gets or sets the content of the annotation.
        """
        GetDllLibPdf().PdfAnnotation_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Text.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfAnnotation_get_Text(self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        GetDllLibPdf().PdfAnnotation_set_Text.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfAnnotation_set_Text(self.Ptr, value)

    @property
    def Flags(self) -> 'PdfAnnotationFlags':
        """
        Gets or sets the annotation flags.
        """
        GetDllLibPdf().PdfAnnotation_get_Flags.argtypes = [c_void_p]
        GetDllLibPdf().PdfAnnotation_get_Flags.restype = c_int
        ret = GetDllLibPdf().PdfAnnotation_get_Flags(self.Ptr)
        objwrapped = PdfAnnotationFlags(ret)
        return objwrapped

    @Flags.setter
    def Flags(self, value: 'PdfAnnotationFlags'):
        GetDllLibPdf().PdfAnnotation_set_Flags.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfAnnotation_set_Flags(self.Ptr, value.value)

    def pipeFlags(self, value: c_int):
        GetDllLibPdf().PdfAnnotation_set_Flags.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfAnnotation_set_Flags(self.Ptr, value)
