from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAutomaticField(PdfGraphicsWidget):
    """
    Represents a field which is calculated before the document saves.
    """

    @property
    def Bounds(self) -> 'RectangleF':
        """
        Gets or sets the bounds of the field.
        """
        GetDllLibPdf().PdfAutomaticField_get_Bounds.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_Bounds.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_Bounds(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @Bounds.setter
    def Bounds(self, value: 'RectangleF'):
        """
        Sets the bounds of the field.
        """
        GetDllLibPdf().PdfAutomaticField_set_Bounds.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_Bounds(self.Ptr, value.Ptr)

    @property
    def Size(self) -> 'SizeF':
        """
        Gets or sets the size of the field.
        """
        GetDllLibPdf().PdfAutomaticField_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_Size.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_Size(self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @Size.setter
    def Size(self, value: 'SizeF'):
        """
        Sets the size of the field.
        """
        GetDllLibPdf().PdfAutomaticField_set_Size.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_Size(self.Ptr, value.Ptr)

    @property
    def Location(self) -> 'PointF':
        """
        Gets or sets the location of the field.
        """
        GetDllLibPdf().PdfAutomaticField_get_Location.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_Location.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_Location(self.Ptr)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @Location.setter
    def Location(self, value: 'PointF'):
        """
        Sets the location of the field.
        """
        GetDllLibPdf().PdfAutomaticField_set_Location.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_Location(self.Ptr, value.Ptr)

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets the font.
        """
        GetDllLibPdf().PdfAutomaticField_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_Font.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_Font(self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets the font.
        """
        GetDllLibPdf().PdfAutomaticField_set_Font.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_Font(self.Ptr, value.Ptr)

    @property
    def Brush(self) -> 'PdfBrush':
        """
        Gets or sets the brush.
        """
        GetDllLibPdf().PdfAutomaticField_get_Brush.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_Brush.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_Brush(self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret

    @Brush.setter
    def Brush(self, value: 'PdfBrush'):
        """
        Sets the brush.
        """
        GetDllLibPdf().PdfAutomaticField_set_Brush.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_Brush(self.Ptr, value.Ptr)

    @property
    def Pen(self) -> 'PdfPen':
        """
        Gets or sets the pen.
        """
        GetDllLibPdf().PdfAutomaticField_get_Pen.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_Pen.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_Pen(self.Ptr)
        ret = None if intPtr == None else PdfPen(intPtr)
        return ret

    @Pen.setter
    def Pen(self, value: 'PdfPen'):
        """
        Sets the pen.
        """
        GetDllLibPdf().PdfAutomaticField_set_Pen.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_Pen(self.Ptr, value.Ptr)

    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the string format.
        """
        GetDllLibPdf().PdfAutomaticField_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfAutomaticField_get_StringFormat.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAutomaticField_get_StringFormat(self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret

    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        """
        Sets the string format.
        """
        GetDllLibPdf().PdfAutomaticField_set_StringFormat.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfAutomaticField_set_StringFormat(self.Ptr, value.Ptr)

    def Draw(self, graphics: 'PdfCanvas', x: float, y: float):
        """
        Draws an element on the Graphics.
        """
        intPtrgraphics: c_void_p = graphics.Ptr

        GetDllLibPdf().PdfAutomaticField_Draw.argtypes = [c_void_p, c_void_p, c_float, c_float]
        GetDllLibPdf().PdfAutomaticField_Draw(self.Ptr, intPtrgraphics, x, y)