from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfBarcode (SpireObject) :
    """
    Represents a base class for all barcode types.
    """
    @property

    def BackColor(self)->'PdfRGBColor':
        """
        Gets or sets the back color of the barcode.
        """
        GetDllLibPdf().PdfBarcode_get_BackColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_BackColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_BackColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BackColor.setter
    def BackColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfBarcode_set_BackColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfBarcode_set_BackColor(self.Ptr, value.Ptr)

    @property

    def BarColor(self)->'PdfRGBColor':
        """
        Gets or sets the bar color of the barcode.
        """
        GetDllLibPdf().PdfBarcode_get_BarColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_BarColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_BarColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BarColor.setter
    def BarColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfBarcode_set_BarColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfBarcode_set_BarColor(self.Ptr, value.Ptr)

    @property

    def TextColor(self)->'PdfRGBColor':
        """
        Gets or sets the text color of the barcode text.
        """
        GetDllLibPdf().PdfBarcode_get_TextColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_TextColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_TextColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @TextColor.setter
    def TextColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfBarcode_set_TextColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfBarcode_set_TextColor(self.Ptr, value.Ptr)

    @property
    def NarrowBarWidth(self)->float:
        """
        Gets or sets the narrow bar width.
        """
        GetDllLibPdf().PdfBarcode_get_NarrowBarWidth.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_NarrowBarWidth.restype=c_float
        ret = GetDllLibPdf().PdfBarcode_get_NarrowBarWidth(self.Ptr)
        return ret

    @NarrowBarWidth.setter
    def NarrowBarWidth(self, value:float):
        GetDllLibPdf().PdfBarcode_set_NarrowBarWidth.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfBarcode_set_NarrowBarWidth(self.Ptr, value)

    @property

    def Text(self)->str:
        """
        Gets or Sets the barcode text.
        """
        GetDllLibPdf().PdfBarcode_get_Text.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_Text.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfBarcode_get_Text(self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibPdf().PdfBarcode_set_Text.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfBarcode_set_Text(self.Ptr, value)

    @property

    def Location(self)->'PointF':
        """
        Gets or sets the location to render barcode in the PDF Document.
        """
        GetDllLibPdf().PdfBarcode_get_Location.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_Location.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_Location(self.Ptr)
        ret = None if intPtr==None else PointF(intPtr)
        return ret


    @Location.setter
    def Location(self, value:'PointF'):
        GetDllLibPdf().PdfBarcode_set_Location.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfBarcode_set_Location(self.Ptr, value.Ptr)

    @property

    def QuietZone(self)->'PdfBarcodeQuietZones':
        """
        Gets or sets the empty area which is to be allocated around the barcode.
        """
        GetDllLibPdf().PdfBarcode_get_QuietZone.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_QuietZone.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_QuietZone(self.Ptr)
        ret = None if intPtr==None else PdfBarcodeQuietZones(intPtr)
        return ret


    @QuietZone.setter
    def QuietZone(self, value:'PdfBarcodeQuietZones'):
        GetDllLibPdf().PdfBarcode_set_QuietZone.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfBarcode_set_QuietZone(self.Ptr, value.Ptr)

    @property
    def BarHeight(self)->float:
        """
        Gets or sets the bar height.
        """
        GetDllLibPdf().PdfBarcode_get_BarHeight.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_BarHeight.restype=c_float
        ret = GetDllLibPdf().PdfBarcode_get_BarHeight(self.Ptr)
        return ret

    @BarHeight.setter
    def BarHeight(self, value:float):
        GetDllLibPdf().PdfBarcode_set_BarHeight.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfBarcode_set_BarHeight(self.Ptr, value)

    @property

    def Size(self)->'SizeF':
        """
        Gets the size of the barcode.
        """
        GetDllLibPdf().PdfBarcode_get_Size.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_Size.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_Size(self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @property

    def Bounds(self)->'RectangleF':
        """
        Gets or sets the rectangular area occupied by the barcode.
        """
        GetDllLibPdf().PdfBarcode_get_Bounds.argtypes=[c_void_p]
        GetDllLibPdf().PdfBarcode_get_Bounds.restype=c_void_p
        intPtr = GetDllLibPdf().PdfBarcode_get_Bounds(self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @Bounds.setter
    def Bounds(self, value:'RectangleF'):
        GetDllLibPdf().PdfBarcode_set_Bounds.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfBarcode_set_Bounds(self.Ptr, value.Ptr)

