from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCalGrayColor(PdfComplexColor):
    """
    Represents a calibrated gray color, based on a CalGray colorspace. 
    """

    @property
    def Gray(self) -> float:
        """
        Gets or sets the gray level for this color. 

        Returns:
            The gray level of this color.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 
            0.0 means the darkest color that can be achieved, and 1.0 means the lightest color.
        """
        GetDllLibPdf().PdfCalGrayColor_get_Gray.argtypes = [c_void_p]
        GetDllLibPdf().PdfCalGrayColor_get_Gray.restype = c_double
        ret = GetDllLibPdf().PdfCalGrayColor_get_Gray(self.Ptr)
        return ret

    @Gray.setter
    def Gray(self, value: float):
        """
        Sets the gray level for this color.

        Args:
            value: The gray level to set.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 
            0.0 means the darkest color that can be achieved, and 1.0 means the lightest color.
        """
        GetDllLibPdf().PdfCalGrayColor_set_Gray.argtypes = [c_void_p, c_double]
        GetDllLibPdf().PdfCalGrayColor_set_Gray(self.Ptr, value)