from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCalRGBColor(PdfComplexColor):
    """
    Represents a calibrated RGB color, based on a CalRGB colorspace.
    """

    @property
    def Blue(self) -> float:
        """
        Gets or sets the Blue value.

        Returns:
            The blue level of this color.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 0.0 means the darkest color that can be achieved, and 1.0 means the lightest.
        """
        GetDllLibPdf().PdfCalRGBColor_get_Blue.argtypes = [c_void_p]
        GetDllLibPdf().PdfCalRGBColor_get_Blue.restype = c_double
        ret = GetDllLibPdf().PdfCalRGBColor_get_Blue(self.Ptr)
        return ret

    @Blue.setter
    def Blue(self, value: float):
        """
        Sets the Blue value.

        Args:
            value: The blue level to set.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 0.0 means the darkest color that can be achieved, and 1.0 means the lightest.
        """
        GetDllLibPdf().PdfCalRGBColor_set_Blue.argtypes = [c_void_p, c_double]
        GetDllLibPdf().PdfCalRGBColor_set_Blue(self.Ptr, value)

    @property
    def Green(self) -> float:
        """
        Gets or sets the green level for this color.

        Returns:
            The green level of this color.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 0.0 means the darkest color that can be achieved, and 1.0 means the lightest color.
        """
        GetDllLibPdf().PdfCalRGBColor_get_Green.argtypes = [c_void_p]
        GetDllLibPdf().PdfCalRGBColor_get_Green.restype = c_double
        ret = GetDllLibPdf().PdfCalRGBColor_get_Green(self.Ptr)
        return ret

    @Green.setter
    def Green(self, value: float):
        """
        Sets the green level for this color.

        Args:
            value: The green level to set.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 0.0 means the darkest color that can be achieved, and 1.0 means the lightest color.
        """
        GetDllLibPdf().PdfCalRGBColor_set_Green.argtypes = [c_void_p, c_double]
        GetDllLibPdf().PdfCalRGBColor_set_Green(self.Ptr, value)

    @property
    def Red(self) -> float:
        """
        Gets or sets the red level for this color.

        Returns:
            The red level of this color.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 0.0 means the darkest color that can be achieved, and 1.0 means the lightest color.
        """
        GetDllLibPdf().PdfCalRGBColor_get_Red.argtypes = [c_void_p]
        GetDllLibPdf().PdfCalRGBColor_get_Red.restype = c_double
        ret = GetDllLibPdf().PdfCalRGBColor_get_Red(self.Ptr)
        return ret

    @Red.setter
    def Red(self, value: float):
        """
        Sets the red level for this color.

        Args:
            value: The red level to set.

        Remarks:
            The acceptable range for this value is [0.0 1.0]. 0.0 means the darkest color that can be achieved, and 1.0 means the lightest color.
        """
        GetDllLibPdf().PdfCalRGBColor_set_Red.argtypes = [c_void_p, c_double]
        GetDllLibPdf().PdfCalRGBColor_set_Red(self.Ptr, value)