from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCollection(IEnumerable):
    """
    Base collection of the pdf objects.
    """

    @property
    def Count(self) -> int:
        """
        Gets number of the elements in the collection.
        :return: The total number of elements in the collection.
        """
        GetDllLibPdf().PdfCollection_get_Count.argtypes = [c_void_p]
        GetDllLibPdf().PdfCollection_get_Count.restype = c_int
        ret = GetDllLibPdf().PdfCollection_get_Count(self.Ptr)
        return ret

    @property
    def List(self) -> 'IList':
        """
        Gets internal list of the collection.
        :return: The internal list of the collection.
        """
        GetDllLibPdf().PdfCollection_get_List.argtypes = [c_void_p]
        GetDllLibPdf().PdfCollection_get_List.restype = c_void_p
        intPtr = GetDllLibPdf().PdfCollection_get_List(self.Ptr)
        ret = None if intPtr == None else IList(intPtr)
        return ret

    def GetEnumerator(self) -> 'IEnumerator':
        """
        Returns an enumerator that iterates through a collection.
        :return: An enumerator that iterates through a collection.
        """
        GetDllLibPdf().PdfCollection_GetEnumerator.argtypes = [c_void_p]
        GetDllLibPdf().PdfCollection_GetEnumerator.restype = c_void_p
        intPtr = GetDllLibPdf().PdfCollection_GetEnumerator(self.Ptr)
        ret = None if intPtr == None else IEnumerator(intPtr)
        return ret