from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfCreationDateField(PdfSingleValueField):
    """
    Represents class to display creation date of the document.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfCreationDateField class.
        """
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateField.restype = c_void_p
        intPtr = GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateField()
        super(PdfCreationDateField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfCreationDateField class with the specified font.
        :param font: The font to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldF(ptrFont)
        super(PdfCreationDateField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfCreationDateField class with the specified font and brush.
        :param font: The font to use for the field.
        :param brush: The brush to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldFB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldFB(ptrFont, ptrBrush)
        super(PdfCreationDateField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfCreationDateField class with the specified font and bounds.
        :param font: The font to use for the field.
        :param bounds: The bounds of the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldFBs.restype = c_void_p
        intPtr = GetDllLibPdf().PdfCreationDateField_CreatePdfCreationDateFieldFBs(ptrFont, ptrBounds)
        super(PdfCreationDateField, self).__init__(intPtr)

    @property
    def DateFormatString(self) -> str:
        """
        Gets or sets the format string.
        :return: The format string.
        """
        GetDllLibPdf().PdfCreationDateField_get_DateFormatString.argtypes = [c_void_p]
        GetDllLibPdf().PdfCreationDateField_get_DateFormatString.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfCreationDateField_get_DateFormatString(self.Ptr))
        return ret

    @DateFormatString.setter
    def DateFormatString(self, value: str):
        """
        Sets the format string.
        :param value: The format string to set.
        """
        GetDllLibPdf().PdfCreationDateField_set_DateFormatString.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfCreationDateField_set_DateFormatString(self.Ptr, value)
