from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDestinationPageNumberField(PdfPageNumberField):
    """
    Represents class which displays destination page's number.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfDestinationPageNumberField class.
        """
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberField.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberField()
        super(PdfDestinationPageNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfDestinationPageNumberField class with the specified font.
        
        Args:
            font (PdfFontBase): The font to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldF(ptrFont)
        super(PdfDestinationPageNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfDestinationPageNumberField class with the specified font and brush.
        
        Args:
            font (PdfFontBase): The font to use for the field.
            brush (PdfBrush): The brush to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldFB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldFB(ptrFont, ptrBrush)
        super(PdfDestinationPageNumberField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfDestinationPageNumberField class with the specified font and bounds.
        
        Args:
            font (PdfFontBase): The font to use for the field.
            bounds (RectangleF): The bounds of the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldFBs.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDestinationPageNumberField_CreatePdfDestinationPageNumberFieldFBs(ptrFont, ptrBounds)
        super(PdfDestinationPageNumberField, self).__init__(intPtr)

    @property
    def PageWidget(self) -> 'PdfPageWidget':
        """
        Gets or sets the PdfPageWidget.
        """
        GetDllLibPdf().PdfDestinationPageNumberField_get_PageWidget.argtypes = [c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_get_PageWidget.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDestinationPageNumberField_get_PageWidget(self.Ptr)
        ret = None if intPtr == None else PdfPageWidget(intPtr)
        return ret

    @PageWidget.setter
    def PageWidget(self, value: 'PdfPageWidget'):
        """
        Sets the PdfPageWidget.
        
        Args:
            value (PdfPageWidget): The PdfPageWidget to set.
        """
        GetDllLibPdf().PdfDestinationPageNumberField_set_PageWidget.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_set_PageWidget(self.Ptr, value.Ptr)

    @property
    def Page(self) -> 'PdfNewPage':
        """
        Gets or sets the page.
        """
        GetDllLibPdf().PdfDestinationPageNumberField_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_get_Page.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDestinationPageNumberField_get_Page(self.Ptr)
        ret = None if intPtr == None else PdfNewPage(intPtr)
        return ret

    @Page.setter
    def Page(self, value: 'PdfNewPage'):
        """
        Sets the page.
        
        Args:
            value (PdfNewPage): The PdfNewPage to set.
        """
        GetDllLibPdf().PdfDestinationPageNumberField_set_Page.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDestinationPageNumberField_set_Page(self.Ptr, value.Ptr)