from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDocumentAuthorField(PdfSingleValueField):
    """
    Represents an automatic field that contains the document's author name.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfDocumentAuthorField class.
        """
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorField.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorField()
        super(PdfDocumentAuthorField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfDocumentAuthorField class with the specified font.

        Args:
            font (PdfFontBase): The font to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldF.argtypes = [c_void_p]
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldF(ptrFont)
        super(PdfDocumentAuthorField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, brush: PdfBrush):
        """
        Initializes a new instance of the PdfDocumentAuthorField class with the specified font and brush.

        Args:
            font (PdfFontBase): The font to use for the field.
            brush (PdfBrush): The brush to use for the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBrush: c_void_p = brush.Ptr
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldFB.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldFB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldFB(ptrFont, ptrBrush)
        super(PdfDocumentAuthorField, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase, bounds: RectangleF):
        """
        Initializes a new instance of the PdfDocumentAuthorField class with the specified font and bounds.

        Args:
            font (PdfFontBase): The font to use for the field.
            bounds (RectangleF): The bounds of the field.
        """
        ptrFont: c_void_p = font.Ptr
        ptrBounds: c_void_p = bounds.Ptr
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldFBs.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldFBs.restype = c_void_p
        intPtr = GetDllLibPdf().PdfDocumentAuthorField_CreatePdfDocumentAuthorFieldFBs(ptrFont, ptrBounds)
        super(PdfDocumentAuthorField, self).__init__(intPtr)