from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfDocumentTemplate (SpireObject) :
    """
    Encapsulates a page template for all the pages in the document.
    """
    @property

    def Left(self)->'PdfPageTemplateElement':
        """
        Gets or sets a left page template.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_Left.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_Left.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_Left(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @Left.setter
    def Left(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_Left.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_Left(self.Ptr, value.Ptr)

    @property

    def Top(self)->'PdfPageTemplateElement':
        """
        Gets or sets a top page template.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_Top.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_Top.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_Top(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @Top.setter
    def Top(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_Top.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_Top(self.Ptr, value.Ptr)

    @property

    def Right(self)->'PdfPageTemplateElement':
        """
        Gets or sets a right page template.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_Right.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_Right.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_Right(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @Right.setter
    def Right(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_Right.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_Right(self.Ptr, value.Ptr)

    @property

    def Bottom(self)->'PdfPageTemplateElement':
        """
        Gets or sets a bottom page template.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_Bottom.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_Bottom.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_Bottom(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @Bottom.setter
    def Bottom(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_Bottom.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_Bottom(self.Ptr, value.Ptr)

    @property

    def EvenLeft(self)->'PdfPageTemplateElement':
        """
        Gets or sets a left page template using on the even pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_EvenLeft.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_EvenLeft.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_EvenLeft(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @EvenLeft.setter
    def EvenLeft(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_EvenLeft.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_EvenLeft(self.Ptr, value.Ptr)

    @property

    def EvenTop(self)->'PdfPageTemplateElement':
        """
        Gets or sets a top page template using on the even pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_EvenTop.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_EvenTop.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_EvenTop(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @EvenTop.setter
    def EvenTop(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_EvenTop.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_EvenTop(self.Ptr, value.Ptr)

    @property

    def EvenRight(self)->'PdfPageTemplateElement':
        """
        Gets or sets a right page template using on the even pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_EvenRight.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_EvenRight.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_EvenRight(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @EvenRight.setter
    def EvenRight(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_EvenRight.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_EvenRight(self.Ptr, value.Ptr)

    @property

    def EvenBottom(self)->'PdfPageTemplateElement':
        """
        Gets or sets a bottom page template using on the even pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_EvenBottom.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_EvenBottom.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_EvenBottom(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @EvenBottom.setter
    def EvenBottom(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_EvenBottom.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_EvenBottom(self.Ptr, value.Ptr)

    @property

    def OddLeft(self)->'PdfPageTemplateElement':
        """
        Gets or sets a left page template using on the odd pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_OddLeft.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_OddLeft.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_OddLeft(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @OddLeft.setter
    def OddLeft(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_OddLeft.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_OddLeft(self.Ptr, value.Ptr)

    @property

    def OddTop(self)->'PdfPageTemplateElement':
        """
        Gets or sets a top page template using on the odd pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_OddTop.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_OddTop.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_OddTop(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @OddTop.setter
    def OddTop(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_OddTop.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_OddTop(self.Ptr, value.Ptr)

    @property

    def OddRight(self)->'PdfPageTemplateElement':
        """
        Gets or sets a right page template using on the odd pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_OddRight.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_OddRight.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_OddRight(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @OddRight.setter
    def OddRight(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_OddRight.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_OddRight(self.Ptr, value.Ptr)

    @property

    def OddBottom(self)->'PdfPageTemplateElement':
        """
        Gets or sets a bottom page template using on the odd pages.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_OddBottom.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_OddBottom.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_OddBottom(self.Ptr)
        ret = None if intPtr==None else PdfPageTemplateElement(intPtr)
        return ret


    @OddBottom.setter
    def OddBottom(self, value:'PdfPageTemplateElement'):
        GetDllLibPdf().PdfDocumentTemplate_set_OddBottom.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_set_OddBottom(self.Ptr, value.Ptr)

    @property

    def Stamps(self)->'PdfStampCollection':
        """
        Gets a collection of stamp elements.
        """
        GetDllLibPdf().PdfDocumentTemplate_get_Stamps.argtypes=[c_void_p]
        GetDllLibPdf().PdfDocumentTemplate_get_Stamps.restype=c_void_p
        intPtr = GetDllLibPdf().PdfDocumentTemplate_get_Stamps(self.Ptr)
        ret = None if intPtr==None else PdfStampCollection(intPtr)
        return ret


