from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfEdges(SpireObject):
    """
    Represents the edges of a PDF object.
    """

    @property
    def Left(self) -> int:
        """
        Gets or sets the left edge.
        """
        GetDllLibPdf().PdfEdges_get_Left.argtypes = [c_void_p]
        GetDllLibPdf().PdfEdges_get_Left.restype = c_int
        ret = GetDllLibPdf().PdfEdges_get_Left(self.Ptr)
        return ret

    @Left.setter
    def Left(self, value: int):
        """
        Sets the left edge.
        """
        GetDllLibPdf().PdfEdges_set_Left.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfEdges_set_Left(self.Ptr, value)

    @property
    def Right(self) -> int:
        """
        Gets or sets the right edge.
        """
        GetDllLibPdf().PdfEdges_get_Right.argtypes = [c_void_p]
        GetDllLibPdf().PdfEdges_get_Right.restype = c_int
        ret = GetDllLibPdf().PdfEdges_get_Right(self.Ptr)
        return ret

    @Right.setter
    def Right(self, value: int):
        """
        Sets the right edge.
        """
        GetDllLibPdf().PdfEdges_set_Right.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfEdges_set_Right(self.Ptr, value)

    @property
    def Top(self) -> int:
        """
        Gets or sets the top edge.
        """
        GetDllLibPdf().PdfEdges_get_Top.argtypes = [c_void_p]
        GetDllLibPdf().PdfEdges_get_Top.restype = c_int
        ret = GetDllLibPdf().PdfEdges_get_Top(self.Ptr)
        return ret

    @Top.setter
    def Top(self, value: int):
        """
        Sets the top edge.
        """
        GetDllLibPdf().PdfEdges_set_Top.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfEdges_set_Top(self.Ptr, value)

    @property
    def Bottom(self) -> int:
        """
        Gets or sets the bottom edge.
        """
        GetDllLibPdf().PdfEdges_get_Bottom.argtypes = [c_void_p]
        GetDllLibPdf().PdfEdges_get_Bottom.restype = c_int
        ret = GetDllLibPdf().PdfEdges_get_Bottom(self.Ptr)
        return ret

    @Bottom.setter
    def Bottom(self, value: int):
        """
        Sets the bottom edge.
        """
        GetDllLibPdf().PdfEdges_set_Bottom.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfEdges_set_Bottom(self.Ptr, value)

    @property
    def All(self) -> int:
        """
        Gets or sets all edges.
        """
        return 0

    @All.setter
    def All(self, value: int):
        """
        Sets all edges.
        """
        GetDllLibPdf().PdfEdges_set_All.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfEdges_set_All(self.Ptr, value)