from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfExtendedAppearance(SpireObject):
    """
    Represents extended appearance of the annotation. It has two states such as On state and Off state.
    """

    @property
    def Normal(self) -> 'PdfAppearanceState':
        """
        Gets the normal appearance of the annotation.
        :return: The object specifies the normal appearance of the annotation.
        """
        GetDllLibPdf().PdfExtendedAppearance_get_Normal.argtypes = [c_void_p]
        GetDllLibPdf().PdfExtendedAppearance_get_Normal.restype = c_void_p
        intPtr = GetDllLibPdf().PdfExtendedAppearance_get_Normal(self.Ptr)
        ret = None if intPtr == None else PdfAppearanceState(intPtr)
        return ret

    @property
    def MouseHover(self) -> 'PdfAppearanceState':
        """
        Gets the appearance when mouse is hovered.
        :return: The object specifies the annotation appearance when the mouse is hovered on it.
        """
        GetDllLibPdf().PdfExtendedAppearance_get_MouseHover.argtypes = [c_void_p]
        GetDllLibPdf().PdfExtendedAppearance_get_MouseHover.restype = c_void_p
        intPtr = GetDllLibPdf().PdfExtendedAppearance_get_MouseHover(self.Ptr)
        ret = None if intPtr == None else PdfAppearanceState(intPtr)
        return ret

    @property
    def Pressed(self) -> 'PdfAppearanceState':
        """
        Gets the pressed state annotation.
        :return: The appearance in pressed state.
        """
        GetDllLibPdf().PdfExtendedAppearance_get_Pressed.argtypes = [c_void_p]
        GetDllLibPdf().PdfExtendedAppearance_get_Pressed.restype = c_void_p
        intPtr = GetDllLibPdf().PdfExtendedAppearance_get_Pressed(self.Ptr)
        ret = None if intPtr == None else PdfAppearanceState(intPtr)
        return ret