from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFieldActions (SpireObject) :
    """
        Represents actions to be performed as response to field events. 
    """
    @property

    def KeyPressed(self)->'PdfJavaScriptAction':
        """
        Gets or sets the JavaScript action to be performed when the user types a keystroke 
            into a text field or combo box or modifies the selection in a scrollable list box. 
            This action can check the keystroke for validity and reject or modify it.
        """
        GetDllLibPdf().PdfFieldActions_get_KeyPressed.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_KeyPressed.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_KeyPressed(self.Ptr)
        ret = None if intPtr==None else PdfJavaScriptAction(intPtr)
        return ret


    @KeyPressed.setter
    def KeyPressed(self, value:'PdfJavaScriptAction'):
        GetDllLibPdf().PdfFieldActions_set_KeyPressed.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_KeyPressed(self.Ptr, value.Ptr)

    @property

    def Format(self)->'PdfJavaScriptAction':
        """
        Gets or sets the JavaScript action to be performed before the field is formatted 
            to display its current value.
        """
        GetDllLibPdf().PdfFieldActions_get_Format.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_Format.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_Format(self.Ptr)
        ret = None if intPtr==None else PdfJavaScriptAction(intPtr)
        return ret


    @Format.setter
    def Format(self, value:'PdfJavaScriptAction'):
        GetDllLibPdf().PdfFieldActions_set_Format.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_Format(self.Ptr, value.Ptr)

    @property

    def Validate(self)->'PdfJavaScriptAction':
        """
        Gets or sets the JavaScript action to be performed
            This action can check the new value for validity.
        """
        GetDllLibPdf().PdfFieldActions_get_Validate.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_Validate.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_Validate(self.Ptr)
        ret = None if intPtr==None else PdfJavaScriptAction(intPtr)
        return ret


    @Validate.setter
    def Validate(self, value:'PdfJavaScriptAction'):
        GetDllLibPdf().PdfFieldActions_set_Validate.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_Validate(self.Ptr, value.Ptr)

    @property

    def Calculate(self)->'PdfJavaScriptAction':
        """
        Gets or sets the JavaScript action to be performed to recalculate the value 
            of this field when that of another field changes.
        """
        GetDllLibPdf().PdfFieldActions_get_Calculate.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_Calculate.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_Calculate(self.Ptr)
        ret = None if intPtr==None else PdfJavaScriptAction(intPtr)
        return ret


    @Calculate.setter
    def Calculate(self, value:'PdfJavaScriptAction'):
        GetDllLibPdf().PdfFieldActions_set_Calculate.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_Calculate(self.Ptr, value.Ptr)

    @property

    def MouseEnter(self)->'PdfAction':
        """

        """
        GetDllLibPdf().PdfFieldActions_get_MouseEnter.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_MouseEnter.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_MouseEnter(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseEnter.setter
    def MouseEnter(self, value:'PdfAction'):
        GetDllLibPdf().PdfFieldActions_set_MouseEnter.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_MouseEnter(self.Ptr, value.Ptr)

    @property

    def MouseLeave(self)->'PdfAction':
        """

        """
        GetDllLibPdf().PdfFieldActions_get_MouseLeave.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_MouseLeave.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_MouseLeave(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseLeave.setter
    def MouseLeave(self, value:'PdfAction'):
        GetDllLibPdf().PdfFieldActions_set_MouseLeave.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_MouseLeave(self.Ptr, value.Ptr)

    @property

    def MouseUp(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is released 
            inside the fields area.
        """
        GetDllLibPdf().PdfFieldActions_get_MouseUp.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_MouseUp.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_MouseUp(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseUp.setter
    def MouseUp(self, value:'PdfAction'):
        GetDllLibPdf().PdfFieldActions_set_MouseUp.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_MouseUp(self.Ptr, value.Ptr)

    @property

    def MouseDown(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the mouse button is pressed inside the 
            fields area.
        """
        GetDllLibPdf().PdfFieldActions_get_MouseDown.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_MouseDown.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_MouseDown(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @MouseDown.setter
    def MouseDown(self, value:'PdfAction'):
        GetDllLibPdf().PdfFieldActions_set_MouseDown.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_MouseDown(self.Ptr, value.Ptr)

    @property

    def GotFocus(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the field receives the 
            input focus.
        """
        GetDllLibPdf().PdfFieldActions_get_GotFocus.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_GotFocus.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_GotFocus(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @GotFocus.setter
    def GotFocus(self, value:'PdfAction'):
        GetDllLibPdf().PdfFieldActions_set_GotFocus.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_GotFocus(self.Ptr, value.Ptr)

    @property

    def LostFocus(self)->'PdfAction':
        """
        Gets or sets the action to be performed when the field loses the 
            input focus.
        """
        GetDllLibPdf().PdfFieldActions_get_LostFocus.argtypes=[c_void_p]
        GetDllLibPdf().PdfFieldActions_get_LostFocus.restype=c_void_p
        intPtr = GetDllLibPdf().PdfFieldActions_get_LostFocus(self.Ptr)
        ret = None if intPtr==None else PdfAction(intPtr)
        return ret


    @LostFocus.setter
    def LostFocus(self, value:'PdfAction'):
        GetDllLibPdf().PdfFieldActions_set_LostFocus.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldActions_set_LostFocus(self.Ptr, value.Ptr)

