from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFieldWidgetItem(SpireObject):
    """
    Represents base class for field's group items.
    """

    @property
    def Bounds(self) -> 'RectangleF':
        """
        Gets or sets the bounds.
        """
        GetDllLibPdf().PdfFieldWidgetItem_get_Bounds.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_get_Bounds.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFieldWidgetItem_get_Bounds(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @Bounds.setter
    def Bounds(self, value: 'RectangleF'):
        """
        Sets the bounds.
        """
        GetDllLibPdf().PdfFieldWidgetItem_set_Bounds.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_set_Bounds(self.Ptr, value.Ptr)

    @property
    def Location(self) -> 'PointF':
        """
        Gets or sets the location.
        """
        GetDllLibPdf().PdfFieldWidgetItem_get_Location.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_get_Location.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFieldWidgetItem_get_Location(self.Ptr)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @Location.setter
    def Location(self, value: 'PointF'):
        """
        Sets the location.
        """
        GetDllLibPdf().PdfFieldWidgetItem_set_Location.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_set_Location(self.Ptr, value.Ptr)

    @property
    def Size(self) -> 'SizeF':
        """
        Gets or sets the size.
        """
        GetDllLibPdf().PdfFieldWidgetItem_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_get_Size.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFieldWidgetItem_get_Size(self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @Size.setter
    def Size(self, value: 'SizeF'):
        """
        Sets the size.
        """
        GetDllLibPdf().PdfFieldWidgetItem_set_Size.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_set_Size(self.Ptr, value.Ptr)

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page.
        """
        GetDllLibPdf().PdfFieldWidgetItem_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldWidgetItem_get_Page.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFieldWidgetItem_get_Page(self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret