from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFileLinkAnnotation(PdfActionLinkAnnotation):
    """
    Represents the annotation link to an external file.
    """

    @dispatch
    def __init__(self, rectangle: RectangleF, fileName: str):
        """
        Initializes a new instance of the PdfFileLinkAnnotation class.

        Args:
            rectangle: A RectangleF object representing the position and size of the annotation.
            fileName: A string specifying the full path to the file to be embedded.
        """
        ptrRec: c_void_p = rectangle.Ptr
        GetDllLibPdf().PdfFileLinkAnnotation_CreatePdfFileLinkAnnotationRF.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFileLinkAnnotation_CreatePdfFileLinkAnnotationRF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFileLinkAnnotation_CreatePdfFileLinkAnnotationRF(ptrRec, fileName)
        super(PdfFileLinkAnnotation, self).__init__(intPtr)

    @property
    def FileName(self) -> str:
        """
        Gets or sets the file name.

        Returns:
            A string value specifying the full path to the file to be embedded.
        """
        GetDllLibPdf().PdfFileLinkAnnotation_get_FileName.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileLinkAnnotation_get_FileName.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfFileLinkAnnotation_get_FileName(self.Ptr))
        return ret

    @FileName.setter
    def FileName(self, value: str):
        """
        Sets the file name.

        Args:
            value: A string specifying the full path to the file to be embedded.
        """
        GetDllLibPdf().PdfFileLinkAnnotation_set_FileName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFileLinkAnnotation_set_FileName(self.Ptr, value)

    @property
    def Action(self) -> 'PdfAction':
        """
        Gets or sets the action.

        Returns:
            The action to be executed when the annotation is activated.
        """
        GetDllLibPdf().PdfFileLinkAnnotation_get_Action.argtypes = [c_void_p]
        GetDllLibPdf().PdfFileLinkAnnotation_get_Action.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFileLinkAnnotation_get_Action(self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @Action.setter
    def Action(self, value: 'PdfAction'):
        """
        Sets the action.

        Args:
            value: The action to be executed when the annotation is activated.
        """
        GetDllLibPdf().PdfFileLinkAnnotation_set_Action.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFileLinkAnnotation_set_Action(self.Ptr, value.Ptr)