from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFont(PdfFontBase):
    """
    Represents a PDF font.
    """

    @dispatch
    def __init__(self, fontFamily: PdfFontFamily, size: float):
        """
        Initializes a new instance of the PdfFont class with the specified font family and size.
        
        Args:
            fontFamily (PdfFontFamily): The font family.
            size (float): The font size.
        """
        enumfontFamily: c_int = fontFamily.value
        GetDllLibPdf().PdfFont_CreatePdfFontFS.argtypes = [c_int, c_float]
        GetDllLibPdf().PdfFont_CreatePdfFontFS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFont_CreatePdfFontFS(enumfontFamily, size)
        super(PdfFont, self).__init__(intPtr)

    @dispatch
    def __init__(self, fontFamily: PdfFontFamily, size: float, style: PdfFontStyle):
        """
        Initializes a new instance of the PdfFont class with the specified font family, size, and style.
        
        Args:
            fontFamily (PdfFontFamily): The font family.
            size (float): The font size.
            style (PdfFontStyle): The font style.
        """
        enumfontFamily: c_int = fontFamily.value
        enumstyle: c_int = style.value
        GetDllLibPdf().PdfFont_CreatePdfFontFSS.argtypes = [c_int, c_float, c_int]
        GetDllLibPdf().PdfFont_CreatePdfFontFSS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFont_CreatePdfFontFSS(enumfontFamily, size, enumstyle)
        super(PdfFont, self).__init__(intPtr)

    """
    Represents one of the 14 standard PDF fonts.
    """
    @property
    def FontFamily(self) -> 'PdfFontFamily':
        """
        Gets the font family.
        
        Returns:
            PdfFontFamily: The font family.
        """
        GetDllLibPdf().PdfFont_get_FontFamily.argtypes = [c_void_p]
        GetDllLibPdf().PdfFont_get_FontFamily.restype = c_int
        ret = GetDllLibPdf().PdfFont_get_FontFamily(self.Ptr)
        objwrapped = PdfFontFamily(ret)
        return objwrapped