from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFormAction(PdfAction):
    """
    Represents the form action base class.
    """

    @property
    def Include(self) -> bool:
        """
        Gets or sets a value indicating whether fields contained in the collection will be included for resetting or submitting.

        If Include property is true, only the fields in this collection will be reset or submitted.
        If Include property is false, the fields in this collection are not reset or submitted and only the remaining form fields are reset or submitted.
        If the collection is null or empty, then all the form fields are reset and the Include property is ignored.

        Returns:
            bool: True if include; otherwise, False.
        """
        GetDllLibPdf().PdfFormAction_get_Include.argtypes = [c_void_p]
        GetDllLibPdf().PdfFormAction_get_Include.restype = c_bool
        ret = GetDllLibPdf().PdfFormAction_get_Include(self.Ptr)
        return ret

    @Include.setter
    def Include(self, value: bool):
        """
        Sets a value indicating whether fields contained in the collection will be included for resetting or submitting.

        Args:
            value (bool): True if include; otherwise, False.
        """
        GetDllLibPdf().PdfFormAction_set_Include.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfFormAction_set_Include(self.Ptr, value)

    @property
    def Fields(self) -> 'PdfFieldCollection':
        """
        Gets the fields.

        Returns:
            PdfFieldCollection: The fields.
        """
        GetDllLibPdf().PdfFormAction_get_Fields.argtypes = [c_void_p]
        GetDllLibPdf().PdfFormAction_get_Fields.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFormAction_get_Fields(self.Ptr)
        ret = None if intPtr == None else PdfFieldCollection(intPtr)
        return ret