from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFormFieldWidgetCollection(PdfFieldCollection):
    """
    Represents field collection of loaded form.
    """

    @dispatch
    def get_Item(self, index: int) -> PdfField:
        """
        Gets the field at the specified index.
        """
        GetDllLibPdf().PdfFormFieldWidgetCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFormFieldWidgetCollection_get_Item.restype = IntPtrWithTypeName
        intPtr = GetDllLibPdf().PdfFormFieldWidgetCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else self._create(intPtr)
        return ret

    def _create(self, intPtrWithTypeName: IntPtrWithTypeName) -> PdfField:
        """
        Creates a PdfField object based on the given IntPtrWithTypeName.
        """
        ret = None
        if intPtrWithTypeName == None:
            return ret
        intPtr = intPtrWithTypeName.intPtr[0] + (intPtrWithTypeName.intPtr[1] << 32)
        strName = PtrToStr(intPtrWithTypeName.typeName)
        if strName == 'Spire.Pdf.Widget.PdfTextBoxFieldWidget':
            ret = PdfTextBoxFieldWidget(intPtr)
        elif strName == 'Spire.Pdf.Widget.PdfCheckBoxWidgetFieldWidget':
            ret = PdfCheckBoxWidgetFieldWidget(intPtr)
        elif strName == 'Spire.Pdf.Widget.PdfRadioButtonListFieldWidget':
            ret = PdfRadioButtonListFieldWidget(intPtr)
        elif strName == 'Spire.Pdf.Widget.PdfListBoxWidgetFieldWidget':
            ret = PdfListBoxWidgetFieldWidget(intPtr)
        elif strName == 'Spire.Pdf.Widget.PdfComboBoxWidgetFieldWidget':
            ret = PdfComboBoxWidgetFieldWidget(intPtr)
        elif strName == 'Spire.Pdf.Annotations.PdfRubberStampAnnotationWidget':
            ret = PdfRubberStampAnnotationWidget(intPtr)
        elif strName == 'Spire.Pdf.Widget.PdfButtonWidgetFieldWidget':
            ret = PdfButtonWidgetFieldWidget(intPtr)
        else:
            ret = PdfField(intPtr)
        return ret

    @dispatch
    def get_Item(self, name: str) -> PdfField:
        """
        Returns field with specified name.
        :param name: The specified field name.
        """
        GetDllLibPdf().PdfFormFieldWidgetCollection_get_ItemN.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFormFieldWidgetCollection_get_ItemN.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFormFieldWidgetCollection_get_ItemN(self.Ptr, name)
        ret = None if intPtr == None else PdfField(intPtr)
        return ret

    @property
    def FormWidget(self) -> 'PdfFormWidget':
        """
        Gets or sets the form.
        """
        GetDllLibPdf().PdfFormFieldWidgetCollection_get_FormWidget.argtypes = [c_void_p]
        GetDllLibPdf().PdfFormFieldWidgetCollection_get_FormWidget.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFormFieldWidgetCollection_get_FormWidget(self.Ptr)
        ret = None if intPtr == None else PdfFormWidget(intPtr)
        return ret

    @FormWidget.setter
    def FormWidget(self, value: 'PdfFormWidget'):
        """
        Sets the form widget.
        :param value: The form widget to set.
        """
        GetDllLibPdf().PdfFormFieldWidgetCollection_set_FormWidget.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFormFieldWidgetCollection_set_FormWidget(self.Ptr, value.Ptr)