from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGoToAction(PdfAction):
    """
    Represents an action which goes to a destination in the current document.
    """
    @dispatch
    def __init__(self, destination: PdfDestination):
        """
        Initializes a new instance of the PdfGoToAction class with the specified destination.
        
        Args:
            destination (PdfDestination): The destination to go to.
        """
        ptrDest: c_void_p = destination.Ptr
        GetDllLibPdf().PdfGoToAction_CreatePdfGoToActionD.argtypes = [c_void_p]
        GetDllLibPdf().PdfGoToAction_CreatePdfGoToActionD.restype = c_void_p
        intPtr = GetDllLibPdf().PdfGoToAction_CreatePdfGoToActionD(ptrDest)
        super(PdfGoToAction, self).__init__(intPtr)
    
    @dispatch
    def __init__(self, newPage):
        """
        Initializes a new instance of the PdfGoToAction class with the specified new page.
        
        Args:
            newPage: The new page to go to.
        """
        ptrPage: c_void_p = newPage.Ptr
        GetDllLibPdf().PdfGoToAction_CreatePdfGoToActionP.argtypes = [c_void_p]
        GetDllLibPdf().PdfGoToAction_CreatePdfGoToActionP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfGoToAction_CreatePdfGoToActionP(ptrPage)
        super(PdfGoToAction, self).__init__(intPtr)
    
    @property
    def Destination(self) -> 'PdfDestination':
        """
        Gets or sets the destination.
        
        Returns:
            PdfDestination: The destination.
        """
        GetDllLibPdf().PdfGoToAction_get_Destination.argtypes = [c_void_p]
        GetDllLibPdf().PdfGoToAction_get_Destination.restype = c_void_p
        intPtr = GetDllLibPdf().PdfGoToAction_get_Destination(self.Ptr)
        ret = None if intPtr == None else PdfDestination(intPtr)
        return ret
    
    @Destination.setter
    def Destination(self, value: 'PdfDestination'):
        """
        Sets the destination.
        
        Args:
            value (PdfDestination): The destination to set.
        """
        GetDllLibPdf().PdfGoToAction_set_Destination.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfGoToAction_set_Destination(self.Ptr, value.Ptr)
