from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGraphicsWidget(SpireObject):
    """
    Represents a base class for all page graphics elements.
    """

    @dispatch
    def Draw(self, graphics: PdfCanvas):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
        """
        intPtrgraphics: c_void_p = graphics.Ptr

        GetDllLibPdf().PdfGraphicsWidget_Draw.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfGraphicsWidget_Draw(self.Ptr, intPtrgraphics)

    @dispatch
    def Draw(self, graphics: PdfCanvas, location: PointF):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
            location (PointF): Location of the element in the Graphics' co-ordinate system.
        """
        intPtrgraphics: c_void_p = graphics.Ptr
        intPtrlocation: c_void_p = location.Ptr

        GetDllLibPdf().PdfGraphicsWidget_DrawGL.argtypes = [c_void_p, c_void_p, c_void_p]
        GetDllLibPdf().PdfGraphicsWidget_DrawGL(self.Ptr, intPtrgraphics, intPtrlocation)

    @dispatch
    def Draw(self, graphics: PdfCanvas, x: float, y: float):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
            x (float): X co-ordinate of the element.
            y (float): Y co-ordinate of the element.
        """
        intPtrgraphics: c_void_p = graphics.Ptr

        GetDllLibPdf().PdfGraphicsWidget_DrawGXY.argtypes = [c_void_p, c_void_p, c_float, c_float]
        GetDllLibPdf().PdfGraphicsWidget_DrawGXY(self.Ptr, intPtrgraphics, x, y)