from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfGridRow(SpireObject):
    """
    Represents a row in a PDF grid.
    """

    @property
    def Cells(self) -> 'PdfGridCellCollection':
        """
        Gets the cells in the row.
        """
        GetDllLibPdf().PdfGridRow_get_Cells.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridRow_get_Cells.restype = c_void_p
        intPtr = GetDllLibPdf().PdfGridRow_get_Cells(self.Ptr)
        ret = None if intPtr == None else PdfGridCellCollection(intPtr)
        return ret

    @property
    def Style(self) -> 'PdfGridRowStyle':
        """
        Gets or sets the style of the row.
        """
        GetDllLibPdf().PdfGridRow_get_Style.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridRow_get_Style.restype = c_void_p
        intPtr = GetDllLibPdf().PdfGridRow_get_Style(self.Ptr)
        ret = None if intPtr == None else PdfGridRowStyle(intPtr)
        return ret

    @Style.setter
    def Style(self, value: 'PdfGridRowStyle'):
        """
        Sets the style of the row.
        """
        GetDllLibPdf().PdfGridRow_set_Style.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfGridRow_set_Style(self.Ptr, value.Ptr)

    @property
    def Height(self) -> float:
        """
        Gets or sets the height of the row.
        The height is equal to the content height plus margin plus half of the top and bottom borders.
        """
        GetDllLibPdf().PdfGridRow_get_Height.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridRow_get_Height.restype = c_float
        ret = GetDllLibPdf().PdfGridRow_get_Height(self.Ptr)
        return ret

    @Height.setter
    def Height(self, value: float):
        """
        Sets the height of the row.
        """
        GetDllLibPdf().PdfGridRow_set_Height.argtypes = [c_void_p, c_float]
        GetDllLibPdf().PdfGridRow_set_Height(self.Ptr, value)

    @property
    def AllowCrossPages(self) -> bool:
        """
        Gets or sets whether the row can cross a page.
        """
        GetDllLibPdf().PdfGridRow_get_AllowCrossPages.argtypes = [c_void_p]
        GetDllLibPdf().PdfGridRow_get_AllowCrossPages.restype = c_bool
        ret = GetDllLibPdf().PdfGridRow_get_AllowCrossPages(self.Ptr)
        return ret

    @AllowCrossPages.setter
    def AllowCrossPages(self, value: bool):
        """
        Sets whether the row can cross a page.
        """
        GetDllLibPdf().PdfGridRow_set_AllowCrossPages.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfGridRow_set_AllowCrossPages(self.Ptr, value)

    def ApplyStyle(self, cellStyle: 'PdfGridCellStyle'):
        """
        Applies the cell style to all the cells present in the row.
        :param cellStyle: The cell style to apply.
        """
        intPtrcellStyle: c_void_p = cellStyle.Ptr

        GetDllLibPdf().PdfGridRow_ApplyStyle.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfGridRow_ApplyStyle(self.Ptr, intPtrcellStyle)