from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayer(SpireObject):
    """
    Represent pdf optional content group.
    Content typically belongs to a single optional content group.
    """

    @property
    def Name(self) -> str:
        """
        Get or set pdf layer name.
        Notice: 
        Name may be is not unique.
        """
        GetDllLibPdf().PdfLayer_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_Name.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfLayer_get_Name(self.Ptr))
        return ret

    @Name.setter
    def Name(self, value: str):
        GetDllLibPdf().PdfLayer_set_Name.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfLayer_set_Name(self.Ptr, value)

    @property
    def ViewState(self) -> 'LayerViewState':
        """
        Get or set pdf layer view state.
        """
        GetDllLibPdf().PdfLayer_get_ViewState.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_ViewState.restype = c_int
        ret = GetDllLibPdf().PdfLayer_get_ViewState(self.Ptr)
        objwrapped = LayerViewState(ret)
        return objwrapped

    @ViewState.setter
    def ViewState(self, value: 'LayerViewState'):
        GetDllLibPdf().PdfLayer_set_ViewState.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLayer_set_ViewState(self.Ptr, value.value)

    @property
    def ExportState(self) -> 'LayerExportState':
        """
        Get or set pdf layer export state.
        """
        GetDllLibPdf().PdfLayer_get_ExportState.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_ExportState.restype = c_int
        ret = GetDllLibPdf().PdfLayer_get_ExportState(self.Ptr)
        objwrapped = LayerExportState(ret)
        return objwrapped

    @ExportState.setter
    def ExportState(self, value: 'LayerExportState'):
        GetDllLibPdf().PdfLayer_set_ExportState.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLayer_set_ExportState(self.Ptr, value.value)

    @property
    def PrintState(self) -> 'LayerPrintState':
        """
        Get or set pdf layer print state.
        """
        GetDllLibPdf().PdfLayer_get_PrintState.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_PrintState.restype = c_int
        ret = GetDllLibPdf().PdfLayer_get_PrintState(self.Ptr)
        objwrapped = LayerPrintState(ret)
        return objwrapped

    @PrintState.setter
    def PrintState(self, value: 'LayerPrintState'):
        GetDllLibPdf().PdfLayer_set_PrintState.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLayer_set_PrintState(self.Ptr, value.value)

    @property
    def Visibility(self) -> 'PdfVisibility':
        """
        Get or set pdf layer visible.
        """
        GetDllLibPdf().PdfLayer_get_Visibility.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_Visibility.restype = c_int
        ret = GetDllLibPdf().PdfLayer_get_Visibility(self.Ptr)
        objwrapped = PdfVisibility(ret)
        return objwrapped

    @Visibility.setter
    def Visibility(self, value: 'PdfVisibility'):
        GetDllLibPdf().PdfLayer_set_Visibility.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLayer_set_Visibility(self.Ptr, value.value)

    @property
    def IsShowOnUI(self) -> bool:
        """
        Get whether the layer shows on user interface or not.
        """
        GetDllLibPdf().PdfLayer_get_IsShowOnUI.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_IsShowOnUI.restype = c_bool
        ret = GetDllLibPdf().PdfLayer_get_IsShowOnUI(self.Ptr)
        return ret

    @property
    def Reference(self) -> str:
        """
        Get reference of the layer.
        """
        GetDllLibPdf().PdfLayer_get_Reference.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayer_get_Reference.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfLayer_get_Reference(self.Ptr))
        return ret

    def CreateGraphics(self, g: 'PdfCanvas') -> 'PdfCanvas':
        """
        Create the layer graphics.
        :param g: The pdf layer container's graphics. eg: PdfPageBase.Canvas ...
        :returns: The pdf layer graphics.
        """
        intPtrg: c_void_p = g.Ptr

        GetDllLibPdf().PdfLayer_CreateGraphics.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayer_CreateGraphics.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayer_CreateGraphics(self.Ptr, intPtrg)
        ret = None if intPtr == None else PdfCanvas(intPtr)
        return ret