from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayoutParams(SpireObject):
    """
    Represents the layout parameters for a PDF page.
    """

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets or sets the PDF page associated with the layout parameters.
        """
        GetDllLibPdf().PdfLayoutParams_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayoutParams_get_Page.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutParams_get_Page(self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @Page.setter
    def Page(self, value: 'PdfPageBase'):
        GetDllLibPdf().PdfLayoutParams_set_Page.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutParams_set_Page(self.Ptr, value.Ptr)

    @property
    def Bounds(self) -> 'RectangleF':
        """
        Gets or sets the bounds of the layout parameters.
        """
        GetDllLibPdf().PdfLayoutParams_get_Bounds.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayoutParams_get_Bounds.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutParams_get_Bounds(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @Bounds.setter
    def Bounds(self, value: 'RectangleF'):
        GetDllLibPdf().PdfLayoutParams_set_Bounds.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutParams_set_Bounds(self.Ptr, value.Ptr)

    @property
    def Format(self) -> 'PdfTextLayout':
        """
        Gets or sets the text layout format for the layout parameters.
        """
        GetDllLibPdf().PdfLayoutParams_get_Format.argtypes = [c_void_p]
        GetDllLibPdf().PdfLayoutParams_get_Format.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayoutParams_get_Format(self.Ptr)
        ret = None if intPtr == None else PdfTextLayout(intPtr)
        return ret

    @Format.setter
    def Format(self, value: 'PdfTextLayout'):
        GetDllLibPdf().PdfLayoutParams_set_Format.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayoutParams_set_Format(self.Ptr, value.Ptr)