from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLineAnnotationWidget(PdfStyledAnnotationWidget):
    """
    Represents the loaded line annotation class.
    """

    @property
    def BackColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the back color of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_BackColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_BackColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLineAnnotationWidget_get_BackColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @BackColor.setter
    def BackColor(self, value: 'PdfRGBColor'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_BackColor.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_set_BackColor(self.Ptr, value.Ptr)

    @property
    def BeginLineStyle(self) -> 'PdfLineEndingStyle':
        """
        Gets or sets the begin line style of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_BeginLineStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_BeginLineStyle.restype = c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_BeginLineStyle(self.Ptr)
        objwrapped = PdfLineEndingStyle(ret)
        return objwrapped

    @BeginLineStyle.setter
    def BeginLineStyle(self, value: 'PdfLineEndingStyle'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_BeginLineStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLineAnnotationWidget_set_BeginLineStyle(self.Ptr, value.value)

    @property
    def CaptionType(self) -> 'PdfLineCaptionType':
        """
        Gets or sets the caption type of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_CaptionType.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_CaptionType.restype = c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_CaptionType(self.Ptr)
        objwrapped = PdfLineCaptionType(ret)
        return objwrapped

    @CaptionType.setter
    def CaptionType(self, value: 'PdfLineCaptionType'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_CaptionType.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLineAnnotationWidget_set_CaptionType(self.Ptr, value.value)

    @property
    def EndLineStyle(self) -> 'PdfLineEndingStyle':
        """
        Gets or sets the end line style of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_EndLineStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_EndLineStyle.restype = c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_EndLineStyle(self.Ptr)
        objwrapped = PdfLineEndingStyle(ret)
        return objwrapped

    @EndLineStyle.setter
    def EndLineStyle(self, value: 'PdfLineEndingStyle'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_EndLineStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLineAnnotationWidget_set_EndLineStyle(self.Ptr, value.value)

    @property
    def InnerLineColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the inner line color of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_InnerLineColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_InnerLineColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLineAnnotationWidget_get_InnerLineColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @InnerLineColor.setter
    def InnerLineColor(self, value: 'PdfRGBColor'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_InnerLineColor.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_set_InnerLineColor(self.Ptr, value.Ptr)

    @property
    def LeaderLine(self) -> int:
        """
        Gets or sets the leader line of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_LeaderLine.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_LeaderLine.restype = c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_LeaderLine(self.Ptr)
        return ret

    @LeaderLine.setter
    def LeaderLine(self, value: int):
        GetDllLibPdf().PdfLineAnnotationWidget_set_LeaderLine.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLineAnnotationWidget_set_LeaderLine(self.Ptr, value)

    @property
    def EndPoint(self) -> 'PointF':
        """
        Gets the endpoint of the annotation, it's at the bottom left
        The origin of coordinate system corresponds to the lower-left corner of page.
        The positive x axis extends horizontally to the right and the positive y axis vertically upward
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_EndPoint.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_EndPoint.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLineAnnotationWidget_get_EndPoint(self.Ptr)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @property
    def StartPoint(self) -> 'PointF':
        """
        Gets the startpoint of the annotation, it's at the bottom left
        The origin of coordinate system corresponds to the lower-left corner of page.
        The positive x axis extends horizontally to the right and the positive y axis vertically upward
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_StartPoint.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_StartPoint.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLineAnnotationWidget_get_StartPoint(self.Ptr)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @property
    def LeaderExt(self) -> int:
        """
        Gets or sets the leader ext of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_LeaderExt.argtypes = [c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_LeaderExt.restype = c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_LeaderExt(self.Ptr)
        return ret

    @LeaderExt.setter
    def LeaderExt(self, value: int):
        GetDllLibPdf().PdfLineAnnotationWidget_set_LeaderExt.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfLineAnnotationWidget_set_LeaderExt(self.Ptr, value)

    @property

    def LineBorder(self)->'LineBorder':
        """
        Gets the line border of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_LineBorder.argtypes=[c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_LineBorder.restype=c_void_p
        intPtr = GetDllLibPdf().PdfLineAnnotationWidget_get_LineBorder(self.Ptr)
        ret = None if intPtr==None else LineBorder(intPtr)
        return ret


    @LineBorder.setter
    def LineBorder(self, value:'LineBorder'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_LineBorder.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_set_LineBorder(self.Ptr, value.Ptr)

    @property
    def LineCaption(self)->bool:
        """
        Gets or sets the line caption of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_LineCaption.argtypes=[c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_LineCaption.restype=c_bool
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_LineCaption(self.Ptr)
        return ret

    @LineCaption.setter
    def LineCaption(self, value:bool):
        GetDllLibPdf().PdfLineAnnotationWidget_set_LineCaption.argtypes=[c_void_p, c_bool]
        GetDllLibPdf().PdfLineAnnotationWidget_set_LineCaption(self.Ptr, value)

    @property

    def LineIntent(self)->'PdfLineIntent':
        """
        Gets or sets the line intent of the annotation.
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_LineIntent.argtypes=[c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_LineIntent.restype=c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_get_LineIntent(self.Ptr)
        objwraped = PdfLineIntent(ret)
        return objwraped

    @LineIntent.setter
    def LineIntent(self, value:'PdfLineIntent'):
        GetDllLibPdf().PdfLineAnnotationWidget_set_LineIntent.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfLineAnnotationWidget_set_LineIntent(self.Ptr, value.value)

    @property

    def Author(self)->str:
        """
        To specifying author
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_Author.argtypes=[c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_Author.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfLineAnnotationWidget_get_Author(self.Ptr))
        return ret


    @Author.setter
    def Author(self, value:str):
        GetDllLibPdf().PdfLineAnnotationWidget_set_Author.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfLineAnnotationWidget_set_Author(self.Ptr, value)

    @property

    def Subject(self)->str:
        """
        To specifying subject
        """
        GetDllLibPdf().PdfLineAnnotationWidget_get_Subject.argtypes=[c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_get_Subject.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfLineAnnotationWidget_get_Subject(self.Ptr))
        return ret


    @Subject.setter
    def Subject(self, value:str):
        GetDllLibPdf().PdfLineAnnotationWidget_set_Subject.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfLineAnnotationWidget_set_Subject(self.Ptr, value)

    def ObjectID(self)->int:
        """
        Represents the Form field identifier
        """
        GetDllLibPdf().PdfLineAnnotationWidget_ObjectID.argtypes=[c_void_p]
        GetDllLibPdf().PdfLineAnnotationWidget_ObjectID.restype=c_int
        ret = GetDllLibPdf().PdfLineAnnotationWidget_ObjectID(self.Ptr)
        return ret