from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListBoxWidgetFieldWidget(PdfChoiceWidgetFieldWidget):
    """
    Represents loaded list box field.
    """

    @property
    def MultiSelect(self) -> bool:
        """
        Gets or sets a value indicating whether the field is multiselectable.
        """
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_get_MultiSelect.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_get_MultiSelect.restype = c_bool
        ret = GetDllLibPdf().PdfListBoxWidgetFieldWidget_get_MultiSelect(self.Ptr)
        return ret

    @MultiSelect.setter
    def MultiSelect(self, value: bool):
        """
        Sets a value indicating whether the field is multiselectable.
        """
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_set_MultiSelect.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_set_MultiSelect(self.Ptr, value)

    @property
    def Items(self) -> 'PdfListWidgetFieldItemCollection':
        """
        Gets the items.
        :return: The collection of list box items.
        """
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_get_Items.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_get_Items.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListBoxWidgetFieldWidget_get_Items(self.Ptr)
        ret = None if intPtr == None else PdfListWidgetFieldItemCollection(intPtr)
        return ret

    def ObjectID(self) -> int:
        """
        Gets the form field identifier.
        :return: The form field identifier.
        """
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfListBoxWidgetFieldWidget_ObjectID.restype = c_int
        ret = GetDllLibPdf().PdfListBoxWidgetFieldWidget_ObjectID(self.Ptr)
        return ret