from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListFieldItem(SpireObject):
    """
    Represents an item of the list fields.
    """

    @dispatch
    def __init__(self, text: str, value: str):
        """
        Initializes a new instance of the PdfListFieldItem class with the specified text and value.

        Args:
            text (str): The text of the list item field.
            value (str): The value of the list item field.
        """
        GetDllLibPdf().PdfListFieldItem_CreatePdfListFieldItemTV.argtypes = [c_wchar_p, c_wchar_p]
        GetDllLibPdf().PdfListFieldItem_CreatePdfListFieldItemTV.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListFieldItem_CreatePdfListFieldItemTV(text, value)
        super(PdfListFieldItem, self).__init__(intPtr)

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfListFieldItem class.
        """
        GetDllLibPdf().PdfListFieldItem_CreatePdfListFieldItem.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListFieldItem_CreatePdfListFieldItem()
        super(PdfListFieldItem, self).__init__(intPtr)

    @property
    def Text(self) -> str:
        """
        Gets or sets the text of the list item field.

        Returns:
            str: The text of the list item field.
        """
        GetDllLibPdf().PdfListFieldItem_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfListFieldItem_get_Text.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfListFieldItem_get_Text(self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        """
        Sets the text of the list item field.

        Args:
            value (str): The text of the list item field.
        """
        GetDllLibPdf().PdfListFieldItem_set_Text.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfListFieldItem_set_Text(self.Ptr, value)

    @property
    def Value(self) -> str:
        """
        Gets or sets the value of the list item field.

        Returns:
            str: The value of the list item field.
        """
        GetDllLibPdf().PdfListFieldItem_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().PdfListFieldItem_get_Value.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfListFieldItem_get_Value(self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the list item field.

        Args:
            value (str): The value of the list item field.
        """
        GetDllLibPdf().PdfListFieldItem_set_Value.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfListFieldItem_set_Value(self.Ptr, value)