from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfListFieldItemCollection(PdfCollection):
    """
    Represents list field item collection.
    """

    def get_Item(self, index: int) -> 'PdfListFieldItem':
        """
        Gets the item at the specified index.

        Args:
            index: The index of the item.

        Returns:
            The PdfListFieldItem object.
        """
        GetDllLibPdf().PdfListFieldItemCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfListFieldItemCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().PdfListFieldItemCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else PdfListFieldItem(intPtr)
        return ret

    def Add(self, item: 'PdfListFieldItem') -> int:
        """
        Adds the specified item to the collection.

        Args:
            item: The PdfListFieldItem object to be added.

        Returns:
            The item.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfListFieldItemCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListFieldItemCollection_Add.restype = c_int
        ret = GetDllLibPdf().PdfListFieldItemCollection_Add(self.Ptr, intPtritem)
        return ret

    def Insert(self, index: int, item: 'PdfListFieldItem'):
        """
        Inserts the list item field at the specified index.

        Args:
            index: The index where the new item should be inserted.
            item: The PdfListFieldItem object to be added to the collection.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfListFieldItemCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().PdfListFieldItemCollection_Insert(self.Ptr, index, intPtritem)

    def Remove(self, item: 'PdfListFieldItem'):
        """
        Removes the specified item from the collection.

        Args:
            item: The PdfListFieldItem object to be removed.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfListFieldItemCollection_Remove.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListFieldItemCollection_Remove(self.Ptr, intPtritem)

    def RemoveAt(self, index: int):
        """
        Removes the item at the specified position.

        Args:
            index: The index where the item should be removed.
        """
        GetDllLibPdf().PdfListFieldItemCollection_RemoveAt.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfListFieldItemCollection_RemoveAt(self.Ptr, index)

    def Contains(self, item: 'PdfListFieldItem') -> bool:
        """
        Determines whether the item is contained in the collection.

        Args:
            item: The PdfListFieldItem object to check.

        Returns:
            True if the item is contained within the collection, False otherwise.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfListFieldItemCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListFieldItemCollection_Contains.restype = c_bool
        ret = GetDllLibPdf().PdfListFieldItemCollection_Contains(self.Ptr, intPtritem)
        return ret

    def IndexOf(self, item: 'PdfListFieldItem') -> int:
        """
        Gets the index of the specified item.

        Args:
            item: The PdfListFieldItem object whose index is requested.

        Returns:
            The index of the given item, -1 if the item does not exist.
        """
        intPtritem: c_void_p = item.Ptr

        GetDllLibPdf().PdfListFieldItemCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfListFieldItemCollection_IndexOf.restype = c_int
        ret = GetDllLibPdf().PdfListFieldItemCollection_IndexOf(self.Ptr, intPtritem)
        return ret

    def Clear(self):
        """
        Clears the collection.
        """
        GetDllLibPdf().PdfListFieldItemCollection_Clear.argtypes = [c_void_p]
        GetDllLibPdf().PdfListFieldItemCollection_Clear(self.Ptr)