from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMarker(PdfMarkerBase):
    """
    Represents bullet for the list.
    """
    @dispatch
    def __init__(self, style: PdfUnorderedMarkerStyle):
        """
        Initializes a new instance of the PdfMarker class.

        Args:
            style (PdfUnorderedMarkerStyle): The PdfUnorderedMarkerStyle.
        """
        enumStyle:c_int = style.value
        GetDllLibPdf().PdfMarker_CreatePdfMarkerS.argtypes = [c_int]
        GetDllLibPdf().PdfMarker_CreatePdfMarkerS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarker_CreatePdfMarkerS(enumStyle)
        super(PdfMarker, self).__init__(intPtr)

    @property
    def Template(self) -> 'PdfTemplate':
        """
        Gets or sets template of the marker.
        """
        GetDllLibPdf().PdfMarker_get_Template.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarker_get_Template.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarker_get_Template(self.Ptr)
        ret = None if intPtr == None else PdfTemplate(intPtr)
        return ret

    @Template.setter
    def Template(self, value: 'PdfTemplate'):
        """
        Sets template of the marker.
        """
        GetDllLibPdf().PdfMarker_set_Template.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfMarker_set_Template(self.Ptr, value.Ptr)

    @property
    def Image(self) -> 'PdfImage':
        """
        Gets or sets image of the marker.
        """
        GetDllLibPdf().PdfMarker_get_Image.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarker_get_Image.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarker_get_Image(self.Ptr)
        ret = None if intPtr == None else PdfImage(intPtr)
        return ret

    @Image.setter
    def Image(self, value: 'PdfImage'):
        """
        Sets image of the marker.
        """
        GetDllLibPdf().PdfMarker_set_Image.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfMarker_set_Image(self.Ptr, value.Ptr)

    @property
    def Text(self) -> str:
        """
        Gets or sets marker text.
        """
        GetDllLibPdf().PdfMarker_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarker_get_Text.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfMarker_get_Text(self.Ptr))
        return ret

    @Text.setter
    def Text(self, value: str):
        """
        Sets marker text.
        """
        GetDllLibPdf().PdfMarker_set_Text.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfMarker_set_Text(self.Ptr, value)

    @property
    def Style(self) -> 'PdfUnorderedMarkerStyle':
        """
        Gets or sets the style.
        """
        GetDllLibPdf().PdfMarker_get_Style.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarker_get_Style.restype = c_int
        ret = GetDllLibPdf().PdfMarker_get_Style(self.Ptr)
        objwrapped = PdfUnorderedMarkerStyle(ret)
        return objwrapped

    @Style.setter
    def Style(self, value: 'PdfUnorderedMarkerStyle'):
        """
        Sets the style.
        """
        GetDllLibPdf().PdfMarker_set_Style.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfMarker_set_Style(self.Ptr, value.value)