from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMarkerBase(SpireObject):
    """
    Represents base class for markers.
    """

    @property
    def Font(self) -> 'PdfFontBase':
        """
        Gets or sets marker font.
        """
        GetDllLibPdf().PdfMarkerBase_get_Font.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarkerBase_get_Font.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarkerBase_get_Font(self.Ptr)
        ret = None if intPtr == None else PdfFontBase(intPtr)
        return ret

    @Font.setter
    def Font(self, value: 'PdfFontBase'):
        """
        Sets marker font.
        """
        GetDllLibPdf().PdfMarkerBase_set_Font.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfMarkerBase_set_Font(self.Ptr, value.Ptr)

    @property
    def Brush(self) -> 'PdfBrush':
        """
        Gets or sets marker brush.
        """
        GetDllLibPdf().PdfMarkerBase_get_Brush.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarkerBase_get_Brush.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarkerBase_get_Brush(self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret

    @Brush.setter
    def Brush(self, value: 'PdfBrush'):
        """
        Sets marker brush.
        """
        GetDllLibPdf().PdfMarkerBase_set_Brush.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfMarkerBase_set_Brush(self.Ptr, value.Ptr)

    @property
    def Pen(self) -> 'PdfPen':
        """
        Gets or sets marker pen.
        """
        GetDllLibPdf().PdfMarkerBase_get_Pen.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarkerBase_get_Pen.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarkerBase_get_Pen(self.Ptr)
        ret = None if intPtr == None else PdfPen(intPtr)
        return ret

    @Pen.setter
    def Pen(self, value: 'PdfPen'):
        """
        Sets marker pen.
        """
        GetDllLibPdf().PdfMarkerBase_set_Pen.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfMarkerBase_set_Pen(self.Ptr, value.Ptr)

    @property
    def StringFormat(self) -> 'PdfStringFormat':
        """
        Gets or sets the format.
        """
        GetDllLibPdf().PdfMarkerBase_get_StringFormat.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarkerBase_get_StringFormat.restype = c_void_p
        intPtr = GetDllLibPdf().PdfMarkerBase_get_StringFormat(self.Ptr)
        ret = None if intPtr == None else PdfStringFormat(intPtr)
        return ret

    @StringFormat.setter
    def StringFormat(self, value: 'PdfStringFormat'):
        """
        Sets the format.
        """
        GetDllLibPdf().PdfMarkerBase_set_StringFormat.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfMarkerBase_set_StringFormat(self.Ptr, value.Ptr)

    @property
    def Alignment(self) -> 'PdfListMarkerAlignment':
        """
        Gets or sets a value indicating whether the marker is situated at the left of the list or at the right of the list.
        """
        GetDllLibPdf().PdfMarkerBase_get_Alignment.argtypes = [c_void_p]
        GetDllLibPdf().PdfMarkerBase_get_Alignment.restype = c_int
        ret = GetDllLibPdf().PdfMarkerBase_get_Alignment(self.Ptr)
        objwrapped = PdfListMarkerAlignment(ret)
        return objwrapped

    @Alignment.setter
    def Alignment(self, value: 'PdfListMarkerAlignment'):
        """
        Sets a value indicating whether the marker is situated at the left of the list or at the right of the list.
        """
        GetDllLibPdf().PdfMarkerBase_set_Alignment.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfMarkerBase_set_Alignment(self.Ptr, value.value)