from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMerger(SpireObject):
    """
    The class can be used to merge pdf documents
    """

    @staticmethod
    #@dispatch
    def MergeByFile(inputFiles: List[str], outputFile: str, pdfMergeOptions: MergerOptions):
        """
        Merge the PDF documents.

        Args:
            inputFiles (List[str]): The input PDF documents.
            outputFile (str): The output PDF document.
            pdfMergeOptions (MergerOptions): Some options when do merge operation.
        """
        countinputFiles = len(inputFiles)
        ArrayTypeinputFiles = c_wchar_p * countinputFiles
        arrayinputFiles = ArrayTypeinputFiles()
        for i in range(0, countinputFiles):
            arrayinputFiles[i] = inputFiles[i]

        intPtrpdfMergeOptions: c_void_p = pdfMergeOptions.Ptr

        GetDllLibPdf().PdfMerger_Merge.argtypes = [c_void_p, ArrayTypeinputFiles, c_wchar_p, c_void_p, c_int]
        GetDllLibPdf().PdfMerger_Merge(None, arrayinputFiles, outputFile, intPtrpdfMergeOptions, countinputFiles)

    @staticmethod
    #@dispatch
    def MergeByStream(inputStreams: List[Stream], outputStream: Stream, pdfMergeOptions: MergerOptions):
        """
        Merge the PDF documents.

        Args:
            inputStreams (List[Stream]): The input PDF documents.
            outputStream (Stream): The output PDF document.
            pdfMergeOptions (MergerOptions): Some options when do merge operation.
        """
        countinputFiles = len(inputStreams)
        ArrayTypeinputFiles = c_void_p * countinputFiles
        arrayinputFiles = ArrayTypeinputFiles()
        for i in range(0, countinputFiles):
            arrayinputFiles[i] = inputStreams[i].Ptr

        intPtroutputFile: c_void_p = outputStream.Ptr
        intPtrpdfMergeOptions: c_void_p = pdfMergeOptions.Ptr

        GetDllLibPdf().PdfMerger_MergeIOP.argtypes = [c_void_p, ArrayTypeinputFiles, c_void_p, c_void_p, c_int]
        GetDllLibPdf().PdfMerger_MergeIOP(None, arrayinputFiles, intPtroutputFile, intPtrpdfMergeOptions, countinputFiles)