from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfMetafile(PdfImage):
    """
    Class representing metafiles.
    """

    @property
    def Quality(self) -> int:
        """
        Get the quality of the metafile.
        """
        GetDllLibPdf().PdfMetafile_get_Quality.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafile_get_Quality.restype = c_long
        ret = GetDllLibPdf().PdfMetafile_get_Quality(self.Ptr)
        return ret

    @Quality.setter
    def Quality(self, value: int):
        """
        Set the quality of the metafile.
        """
        GetDllLibPdf().PdfMetafile_set_Quality.argtypes = [c_void_p, c_long]
        GetDllLibPdf().PdfMetafile_set_Quality(self.Ptr, value)

    @property
    def PageScale(self) -> float:
        """
        Get the page scale of the metafile.
        """
        GetDllLibPdf().PdfMetafile_get_PageScale.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafile_get_PageScale.restype = c_float
        ret = GetDllLibPdf().PdfMetafile_get_PageScale(self.Ptr)
        return ret

    @PageScale.setter
    def PageScale(self, value: float):
        """
        Set the page scale of the metafile.
        """
        GetDllLibPdf().PdfMetafile_set_PageScale.argtypes = [c_void_p, c_float]
        GetDllLibPdf().PdfMetafile_set_PageScale(self.Ptr, value)

    @property
    def PageUnit(self) -> 'GraphicsUnit':
        """
        Get the page unit of the metafile.
        """
        GetDllLibPdf().PdfMetafile_get_PageUnit.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafile_get_PageUnit.restype = c_int
        ret = GetDllLibPdf().PdfMetafile_get_PageUnit(self.Ptr)
        objwrapped = GraphicsUnit(ret)
        return objwrapped

    @PageUnit.setter
    def PageUnit(self, value: 'GraphicsUnit'):
        """
        Set the page unit of the metafile.
        """
        GetDllLibPdf().PdfMetafile_set_PageUnit.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfMetafile_set_PageUnit(self.Ptr, value.value)

    def Dispose(self):
        """
        Dispose the metafile.
        """
        GetDllLibPdf().PdfMetafile_Dispose.argtypes = [c_void_p]
        GetDllLibPdf().PdfMetafile_Dispose(self.Ptr)

    def SetTransparency(self, alphaPen: float, alphaBrush: float, blendMode: 'PdfBlendMode', transparency: bool):
        """
        Set the transparency of the metafile.
        """
        enumblendMode: c_int = blendMode.value

        GetDllLibPdf().PdfMetafile_SetTransparency.argtypes = [c_void_p, c_float, c_float, c_int, c_bool]
        GetDllLibPdf().PdfMetafile_SetTransparency(self.Ptr, alphaPen, alphaBrush, enumblendMode, transparency)