from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPageTemplateElement (SpireObject) :
    """
    Describes a page template object that can be used as header/footer, watermark or stamp.
    """
    @dispatch
    def __init__(self, bounds:RectangleF):
        ptrBounds:c_void_p = bounds.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementB.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementB(ptrBounds)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, bounds:RectangleF,page):
        ptrBounds:c_void_p = bounds.Ptr
        ptrPage:c_void_p = page.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementBP.argtypes=[c_void_p,c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementBP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementBP(ptrBounds,ptrPage)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, location:PointF,size:SizeF):
        ptrPoint:c_void_p = location.Ptr
        ptrSize:c_void_p = size.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementLS.argtypes=[c_void_p,c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementLS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementLS(ptrPoint,ptrSize)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, location:PointF,size:SizeF,page):
        ptrPoint:c_void_p = location.Ptr
        ptrSize:c_void_p = size.Ptr
        ptrPage:c_void_p = page.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementLSP.argtypes=[c_void_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementLSP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementLSP(ptrPoint,ptrSize,ptrPage)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, size:SizeF):
        ptrSize:c_void_p = size.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementS.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementS(ptrSize)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, width:float,height:float):
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementWH.argtypes=[c_float,c_float]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementWH.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementWH(width,height)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, width:float,height:float,page):
        ptrPage:c_void_p = page.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementWHP.argtypes=[c_float,c_float,c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementWHP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementWHP(width,height,ptrPage)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, x:float,y:float,width:float,height:float):
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementXYWH.argtypes=[c_float,c_float,c_float,c_float]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementXYWH.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementXYWH(x,y,width,height)
        super(PdfPageTemplateElement, self).__init__(intPtr)
    @dispatch
    def __init__(self, x:float,y:float,width:float,height:float,page):
        ptrPage:c_void_p = page.Ptr
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementXYWHP.argtypes=[c_float,c_float,c_float,c_float,c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementXYWHP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_CreatePdfPageTemplateElementXYWHP(x,y,width,height,ptrPage)
        super(PdfPageTemplateElement, self).__init__(intPtr)

    @property

    def Dock(self)->'PdfDockStyle':
        """
        Gets or sets the dock style of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Dock.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Dock.restype=c_int
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Dock(self.Ptr)
        objwraped = PdfDockStyle(ret)
        return objwraped

    @Dock.setter
    def Dock(self, value:'PdfDockStyle'):
        GetDllLibPdf().PdfPageTemplateElement_set_Dock.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfPageTemplateElement_set_Dock(self.Ptr, value.value)

    @property

    def Alignment(self)->'PdfAlignmentStyle':
        """
        Gets or sets alignment of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Alignment.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Alignment.restype=c_int
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Alignment(self.Ptr)
        objwraped = PdfAlignmentStyle(ret)
        return objwraped

    @Alignment.setter
    def Alignment(self, value:'PdfAlignmentStyle'):
        GetDllLibPdf().PdfPageTemplateElement_set_Alignment.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfPageTemplateElement_set_Alignment(self.Ptr, value.value)

    @property
    def Foreground(self)->bool:
        """
        Indicates whether the page template is located in front of 
            the page layers or behind of it.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Foreground.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Foreground.restype=c_bool
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Foreground(self.Ptr)
        return ret

    @Foreground.setter
    def Foreground(self, value:bool):
        GetDllLibPdf().PdfPageTemplateElement_set_Foreground.argtypes=[c_void_p, c_bool]
        GetDllLibPdf().PdfPageTemplateElement_set_Foreground(self.Ptr, value)

    @property
    def Background(self)->bool:
        """
        Indicates whether the page template is located behind of 
            the page layers or in front of it.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Background.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Background.restype=c_bool
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Background(self.Ptr)
        return ret

    @Background.setter
    def Background(self, value:bool):
        GetDllLibPdf().PdfPageTemplateElement_set_Background.argtypes=[c_void_p, c_bool]
        GetDllLibPdf().PdfPageTemplateElement_set_Background(self.Ptr, value)

    @property

    def Location(self)->'PointF':
        """
        Gets or sets location of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Location.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Location.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_get_Location(self.Ptr)
        ret = None if intPtr==None else PointF(intPtr)
        return ret


    @Location.setter
    def Location(self, value:'PointF'):
        GetDllLibPdf().PdfPageTemplateElement_set_Location.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_set_Location(self.Ptr, value.Ptr)

    @property
    def X(self)->float:
        """
        Gets or sets X co-ordinate of the template element on the page.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_X.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_X.restype=c_float
        ret = GetDllLibPdf().PdfPageTemplateElement_get_X(self.Ptr)
        return ret

    @X.setter
    def X(self, value:float):
        GetDllLibPdf().PdfPageTemplateElement_set_X.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPageTemplateElement_set_X(self.Ptr, value)

    @property
    def Y(self)->float:
        """
        Gets or sets Y co-ordinate of the template element on the page.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Y.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Y.restype=c_float
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Y(self.Ptr)
        return ret

    @Y.setter
    def Y(self, value:float):
        GetDllLibPdf().PdfPageTemplateElement_set_Y.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPageTemplateElement_set_Y(self.Ptr, value)

    @property

    def Size(self)->'SizeF':
        """
        Gets or sets size of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Size.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Size.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_get_Size(self.Ptr)
        ret = None if intPtr==None else SizeF(intPtr)
        return ret


    @Size.setter
    def Size(self, value:'SizeF'):
        GetDllLibPdf().PdfPageTemplateElement_set_Size.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_set_Size(self.Ptr, value.Ptr)

    @property
    def Width(self)->float:
        """
        Gets or sets width of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Width.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Width.restype=c_float
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Width(self.Ptr)
        return ret

    @Width.setter
    def Width(self, value:float):
        GetDllLibPdf().PdfPageTemplateElement_set_Width.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPageTemplateElement_set_Width(self.Ptr, value)

    @property
    def Height(self)->float:
        """
        Gets or sets height of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Height.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Height.restype=c_float
        ret = GetDllLibPdf().PdfPageTemplateElement_get_Height(self.Ptr)
        return ret

    @Height.setter
    def Height(self, value:float):
        GetDllLibPdf().PdfPageTemplateElement_set_Height.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPageTemplateElement_set_Height(self.Ptr, value)

    @property

    def Bounds(self)->'RectangleF':
        """
        Gets or sets bounds of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Bounds.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Bounds.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_get_Bounds(self.Ptr)
        ret = None if intPtr==None else RectangleF(intPtr)
        return ret


    @Bounds.setter
    def Bounds(self, value:'RectangleF'):
        GetDllLibPdf().PdfPageTemplateElement_set_Bounds.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_set_Bounds(self.Ptr, value.Ptr)

    @property

    def Graphics(self)->'PdfCanvas':
        """
        Gets graphics context of the page template element.
        """
        GetDllLibPdf().PdfPageTemplateElement_get_Graphics.argtypes=[c_void_p]
        GetDllLibPdf().PdfPageTemplateElement_get_Graphics.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPageTemplateElement_get_Graphics(self.Ptr)
        ret = None if intPtr==None else PdfCanvas(intPtr)
        return ret


