from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPen (SpireObject) :
    """
    A class defining settings for drawing operations.
    """
    @dispatch
    def __init__(self, rgbColor:PdfRGBColor):
        ptrColor:c_void_p = rgbColor.Ptr

        GetDllLibPdf().PdfPen_CreatePdfPenRC.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_CreatePdfPenRC.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPen_CreatePdfPenRC(ptrColor)
        super(PdfPen, self).__init__(intPtr)

    @dispatch
    def __init__(self, color:Color):
        ptrColor:c_void_p = color.Ptr

        GetDllLibPdf().PdfPen_CreatePdfPenCoC.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_CreatePdfPenCoC.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPen_CreatePdfPenCoC(ptrColor)
        super(PdfPen, self).__init__(intPtr)

    @dispatch
    def __init__(self, rgbColor:PdfRGBColor,width:float ):
        ptrColor:c_void_p = rgbColor.Ptr

        GetDllLibPdf().PdfPen_CreatePdfPenCW.argtypes=[c_void_p,c_float]
        GetDllLibPdf().PdfPen_CreatePdfPenCW.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPen_CreatePdfPenCW(ptrColor,width)
        super(PdfPen, self).__init__(intPtr)

    @dispatch
    def __init__(self, brush:PdfBrush):
        ptrBrush:c_void_p = brush.Ptr

        GetDllLibPdf().PdfPen_CreatePdfPenB.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_CreatePdfPenB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPen_CreatePdfPenB(ptrBrush)
        super(PdfPen, self).__init__(intPtr)

    @dispatch
    def __init__(self, brush:PdfBrush,width:float ):
        ptrBrush:c_void_p = brush.Ptr

        GetDllLibPdf().PdfPen_CreatePdfPenBW.argtypes=[c_void_p,c_float]
        GetDllLibPdf().PdfPen_CreatePdfPenBW.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPen_CreatePdfPenBW(ptrBrush,width)
        super(PdfPen, self).__init__(intPtr)

    @dispatch
    def __init__(self, cmpColor:PdfComplexColor):
        ptrColor:c_void_p = cmpColor.Ptr

        GetDllLibPdf().PdfPen_CreatePdfPenCC.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_CreatePdfPenCC.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPen_CreatePdfPenCC(ptrColor)
        super(PdfPen, self).__init__(intPtr)

    @property

    def Brush(self)->'PdfBrush':
        """
        Gets or sets the brush, which specifies the pen behaviour.
		If the brush is set, the color values are ignored,except for PdfSolidBrush.
        """
        GetDllLibPdf().PdfPen_get_Brush.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_Brush.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPen_get_Brush(self.Ptr)
        ret = None if intPtr==None else PdfBrush(intPtr)
        return ret


    @Brush.setter
    def Brush(self, value:'PdfBrush'):
        GetDllLibPdf().PdfPen_set_Brush.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfPen_set_Brush(self.Ptr, value.Ptr)

    @property

    def Color(self)->'PdfRGBColor':
        """
        Gets or sets the color of the pen.
        """
        GetDllLibPdf().PdfPen_get_Color.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_Color.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPen_get_Color(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @Color.setter
    def Color(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfPen_set_Color.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfPen_set_Color(self.Ptr, value.Ptr)

    @property
    def DashOffset(self)->float:
        """
        Gets or sets the dash offset of the pen.
        """
        GetDllLibPdf().PdfPen_get_DashOffset.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_DashOffset.restype=c_float
        ret = GetDllLibPdf().PdfPen_get_DashOffset(self.Ptr)
        return ret

    @DashOffset.setter
    def DashOffset(self, value:float):
        GetDllLibPdf().PdfPen_set_DashOffset.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPen_set_DashOffset(self.Ptr, value)

    @property

    def DashPattern(self)->List[float]:
        """
        Gets or sets the dash pattern of the pen.
        """
        GetDllLibPdf().PdfPen_get_DashPattern.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_DashPattern.restype=IntPtrArray
        intPtrArray = GetDllLibPdf().PdfPen_get_DashPattern(self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @DashPattern.setter
    def DashPattern(self, value:List[float]):
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfPen_set_DashPattern.argtypes=[c_void_p, ArrayType, c_int]
        GetDllLibPdf().PdfPen_set_DashPattern(self.Ptr, vArray, vCount)

    @property

    def DashStyle(self)->'PdfDashStyle':
        """
        Gets or sets the dash style of the pen.
        """
        GetDllLibPdf().PdfPen_get_DashStyle.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_DashStyle.restype=c_int
        ret = GetDllLibPdf().PdfPen_get_DashStyle(self.Ptr)
        objwraped = PdfDashStyle(ret)
        return objwraped

    @DashStyle.setter
    def DashStyle(self, value:'PdfDashStyle'):
        GetDllLibPdf().PdfPen_set_DashStyle.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfPen_set_DashStyle(self.Ptr, value.value)

    @property

    def LineCap(self)->'PdfLineCap':
        """
        Gets or sets the line cap of the pen.
        """
        GetDllLibPdf().PdfPen_get_LineCap.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_LineCap.restype=c_int
        ret = GetDllLibPdf().PdfPen_get_LineCap(self.Ptr)
        objwraped = PdfLineCap(ret)
        return objwraped

    @LineCap.setter
    def LineCap(self, value:'PdfLineCap'):
        GetDllLibPdf().PdfPen_set_LineCap.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfPen_set_LineCap(self.Ptr, value.value)

    @property

    def LineJoin(self)->'PdfLineJoin':
        """
        Gets or sets the line join style of the pen.
        """
        GetDllLibPdf().PdfPen_get_LineJoin.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_LineJoin.restype=c_int
        ret = GetDllLibPdf().PdfPen_get_LineJoin(self.Ptr)
        objwraped = PdfLineJoin(ret)
        return objwraped

    @LineJoin.setter
    def LineJoin(self, value:'PdfLineJoin'):
        GetDllLibPdf().PdfPen_set_LineJoin.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfPen_set_LineJoin(self.Ptr, value.value)

    @property
    def Width(self)->float:
        """
        Gets or sets the width of the pen.
        """
        GetDllLibPdf().PdfPen_get_Width.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_Width.restype=c_float
        ret = GetDllLibPdf().PdfPen_get_Width(self.Ptr)
        return ret

    @Width.setter
    def Width(self, value:float):
        GetDllLibPdf().PdfPen_set_Width.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPen_set_Width(self.Ptr, value)

    @property
    def MiterLimit(self)->float:
        """
        Gets or sets the miter limit.
        """
        GetDllLibPdf().PdfPen_get_MiterLimit.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_get_MiterLimit.restype=c_float
        ret = GetDllLibPdf().PdfPen_get_MiterLimit(self.Ptr)
        return ret

    @MiterLimit.setter
    def MiterLimit(self, value:float):
        GetDllLibPdf().PdfPen_set_MiterLimit.argtypes=[c_void_p, c_float]
        GetDllLibPdf().PdfPen_set_MiterLimit(self.Ptr, value)


    def Clone(self)->'PdfPen':
        """
        Clones this instance.
		
        Returns:
            PdfPen: A new pen with the same properties.
        """
        GetDllLibPdf().PdfPen_Clone.argtypes=[c_void_p]
        GetDllLibPdf().PdfPen_Clone.restype=c_void_p
        intPtr = GetDllLibPdf().PdfPen_Clone(self.Ptr)
        ret = None if intPtr==None else PdfPen(intPtr)
        return ret


