from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPieceInfo(SpireObject):
    """
    Represents the pdf piece info can used to hold private application datas.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfPieceInfo class.
        """
        GetDllLibPdf().PdfPieceInfo_CreatePdfPieceInfo.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPieceInfo_CreatePdfPieceInfo()
        super(PdfPieceInfo, self).__init__(intPtr)

    def AddApplicationData(self, applicationName: str, privateData: str):
        """
        Add application data.

        Args:
            applicationName: The application name.
            privateData: The private data.
        """
        GetDllLibPdf().PdfPieceInfo_AddApplicationData.argtypes = [c_void_p, c_wchar_p, c_wchar_p]
        GetDllLibPdf().PdfPieceInfo_AddApplicationData(self.Ptr, applicationName, privateData)

    def RemoveApplicationData(self, applicationName: str):
        """
        Remove the application data.

        Args:
            applicationName: The application name.
        """
        GetDllLibPdf().PdfPieceInfo_RemoveApplicationData.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfPieceInfo_RemoveApplicationData(self.Ptr, applicationName)