from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfRadioButtonWidgetItem(PdfStateWidgetItem):
    """
    Represents radio button field of an existing PDF document's form.
    """

    @property
    def Value(self) -> str:
        """
        Gets or sets the value.

        Returns:
            The value of the radio button item.
        """
        GetDllLibPdf().PdfRadioButtonWidgetItem_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadioButtonWidgetItem_get_Value.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfRadioButtonWidgetItem_get_Value(self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the radio button item.

        Args:
            value: The value to be set.
        """
        GetDllLibPdf().PdfRadioButtonWidgetItem_set_Value.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfRadioButtonWidgetItem_set_Value(self.Ptr, value)

    @property
    def Selected(self) -> bool:
        """
        Gets or sets a value indicating whether this radio button item is selected.

        Returns:
            True if the radio button item is selected, False otherwise.
        """
        GetDllLibPdf().PdfRadioButtonWidgetItem_get_Selected.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadioButtonWidgetItem_get_Selected.restype = c_bool
        ret = GetDllLibPdf().PdfRadioButtonWidgetItem_get_Selected(self.Ptr)
        return ret

    @Selected.setter
    def Selected(self, value: bool):
        """
        Sets the value indicating whether this radio button item is selected.

        Args:
            value: True if the radio button item is selected, False otherwise.
        """
        GetDllLibPdf().PdfRadioButtonWidgetItem_set_Selected.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfRadioButtonWidgetItem_set_Selected(self.Ptr, value)