from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSeparationColorSpace (  PdfColorSpaces) :
    """
    Represents a separation colorspace
    """
    @dispatch
    def __init__(self, colorant:str,baseColor:PdfRGBColor):
        ptrColor:c_void_p = baseColor.Ptr

        GetDllLibPdf().PdfSeparationColorSpace_CreatePdfSeparationColorSpaceCB.argtypes=[c_wchar_p,c_void_p]
        GetDllLibPdf().PdfSeparationColorSpace_CreatePdfSeparationColorSpaceCB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSeparationColorSpace_CreatePdfSeparationColorSpaceCB(colorant,ptrColor)
        super(PdfSeparationColorSpace, self).__init__(intPtr)

    @property

    def BaseColor(self)->'PdfRGBColor':
        """
        The base color to be used.
        """
        GetDllLibPdf().PdfSeparationColorSpace_get_BaseColor.argtypes=[c_void_p]
        GetDllLibPdf().PdfSeparationColorSpace_get_BaseColor.restype=c_void_p
        intPtr = GetDllLibPdf().PdfSeparationColorSpace_get_BaseColor(self.Ptr)
        ret = None if intPtr==None else PdfRGBColor(intPtr)
        return ret


    @BaseColor.setter
    def BaseColor(self, value:'PdfRGBColor'):
        GetDllLibPdf().PdfSeparationColorSpace_set_BaseColor.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfSeparationColorSpace_set_BaseColor(self.Ptr, value.Ptr)

    @property

    def Colorant(self)->str:
        """
        The name of the colorant.
        """
        GetDllLibPdf().PdfSeparationColorSpace_get_Colorant.argtypes=[c_void_p]
        GetDllLibPdf().PdfSeparationColorSpace_get_Colorant.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfSeparationColorSpace_get_Colorant(self.Ptr))
        return ret


    @Colorant.setter
    def Colorant(self, value:str):
        GetDllLibPdf().PdfSeparationColorSpace_set_Colorant.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSeparationColorSpace_set_Colorant(self.Ptr, value)

#
#    def GetProfileData(self)->List['Byte']:
#        """
#        Get the profile data.
#    <returns>The profile data</returns>
#        """
#        GetDllLibPdf().PdfSeparationColorSpace_GetProfileData.argtypes=[c_void_p]
#        GetDllLibPdf().PdfSeparationColorSpace_GetProfileData.restype=IntPtrArray
#        intPtrArray = GetDllLibPdf().PdfSeparationColorSpace_GetProfileData(self.Ptr)
#        ret = GetVectorFromArray(intPtrArray, Byte)
#        return ret


