from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSignatureStyledField(PdfField):
    """
    Represents form's field with style parameters.
    """

    @property
    def Bounds(self) -> 'RectangleF':
        """
        Gets or sets the bounds.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_Bounds.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_Bounds.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureStyledField_get_Bounds(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @Bounds.setter
    def Bounds(self, value: 'RectangleF'):
        """
        Sets the bounds.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_Bounds.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_set_Bounds(self.Ptr, value.Ptr)

    @property
    def Location(self) -> 'PointF':
        """
        Gets or sets the location.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_Location.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_Location.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureStyledField_get_Location(self.Ptr)
        ret = None if intPtr == None else PointF(intPtr)
        return ret

    @Location.setter
    def Location(self, value: 'PointF'):
        """
        Sets the location.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_Location.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_set_Location(self.Ptr, value.Ptr)

    @property
    def Size(self) -> 'SizeF':
        """
        Gets or sets the size.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_Size.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureStyledField_get_Size(self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @Size.setter
    def Size(self, value: 'SizeF'):
        """
        Sets the size.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_Size.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_set_Size(self.Ptr, value.Ptr)

    @property
    def BorderColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the color of the border.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_BorderColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_BorderColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureStyledField_get_BorderColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @BorderColor.setter
    def BorderColor(self, value: 'PdfRGBColor'):
        """
        Sets the color of the border.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_BorderColor.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_set_BorderColor(self.Ptr, value.Ptr)

    @property
    def BackColor(self) -> 'PdfRGBColor':
        """
        Gets or sets the color of the background.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_BackColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_BackColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureStyledField_get_BackColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @BackColor.setter
    def BackColor(self, value: 'PdfRGBColor'):
        """
        Sets the color of the background.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_BackColor.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_set_BackColor(self.Ptr, value.Ptr)

    @property
    def BorderWidth(self) -> float:
        """
        Gets or sets the width of the border.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_BorderWidth.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_BorderWidth.restype = c_float
        ret = GetDllLibPdf().PdfSignatureStyledField_get_BorderWidth(self.Ptr)
        return ret

    @BorderWidth.setter
    def BorderWidth(self, value: float):
        """
        Sets the width of the border.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_BorderWidth.argtypes = [c_void_p, c_float]
        GetDllLibPdf().PdfSignatureStyledField_set_BorderWidth(self.Ptr, value)

    @property
    def HighlightMode(self) -> 'PdfHighlightMode':
        """
        Gets or sets the highlighting mode.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_HighlightMode.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_HighlightMode.restype = c_int
        ret = GetDllLibPdf().PdfSignatureStyledField_get_HighlightMode(self.Ptr)
        objwrapped = PdfHighlightMode(ret)
        return objwrapped

    @HighlightMode.setter
    def HighlightMode(self, value: 'PdfHighlightMode'):
        """
        Sets the highlighting mode.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_HighlightMode.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSignatureStyledField_set_HighlightMode(self.Ptr, value.value)

    @property
    def Actions(self) -> 'PdfFieldActions':
        """
        Gets the actions of the field.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_Actions.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_Actions.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSignatureStyledField_get_Actions(self.Ptr)
        ret = None if intPtr == None else PdfFieldActions(intPtr)
        return ret

    @property
    def BorderStyle(self) -> 'PdfBorderStyle':
        """
        Gets or sets the border style.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_BorderStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_BorderStyle.restype = c_int
        ret = GetDllLibPdf().PdfSignatureStyledField_get_BorderStyle(self.Ptr)
        objwrapped = PdfBorderStyle(ret)
        return objwrapped

    @BorderStyle.setter
    def BorderStyle(self, value: 'PdfBorderStyle'):
        """
        Sets the border style.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_BorderStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSignatureStyledField_set_BorderStyle(self.Ptr, value.value)

    @property
    def Visible(self) -> bool:
        """
        Gets or sets a value indicating whether this is visible.
        """
        GetDllLibPdf().PdfSignatureStyledField_get_Visible.argtypes = [c_void_p]
        GetDllLibPdf().PdfSignatureStyledField_get_Visible.restype = c_bool
        ret = GetDllLibPdf().PdfSignatureStyledField_get_Visible(self.Ptr)
        return ret

    @Visible.setter
    def Visible(self, value: bool):
        """
        Sets a value indicating whether this is visible.
        """
        GetDllLibPdf().PdfSignatureStyledField_set_Visible.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfSignatureStyledField_set_Visible(self.Ptr, value)