from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSortedList(PdfListBase):
    """
    Represents a sorted list.
    """

    @dispatch
    def __init__(self):
        """
        Initializes a new instance of the PdfSortedList class.
        """
        GetDllLibPdf().PdfSortedList_CreatePdfSortedList.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedList()
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, text: str):
        """
        Initializes a new instance of the PdfSortedList class with the specified text.
        :param text: The text to initialize the sorted list with.
        """
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListT.argtypes = [c_wchar_p]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListT.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListT(text)
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, font: PdfFontBase):
        """
        Initializes a new instance of the PdfSortedList class with the specified font.
        :param font: The font to initialize the sorted list with.
        """
        ptrFont: c_void_p = font.Ptr
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListF.argtypes = [c_void_p]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListF(ptrFont)
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, style: PdfNumberStyle):
        """
        Initializes a new instance of the PdfSortedList class with the specified number style.
        :param style: The number style to initialize the sorted list with.
        """
        enumStyle: c_int = style.value
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListS.argtypes = [c_int]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListS(enumStyle)
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, items: PdfListItemCollection):
        """
        Initializes a new instance of the PdfSortedList class with the specified item collection.
        :param items: The item collection to initialize the sorted list with.
        """
        ptrItem: c_void_p = items.Ptr
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListI.argtypes = [c_void_p]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListI.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListI(ptrItem)
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, marker: PdfOrderedMarker):
        """
        Initializes a new instance of the PdfSortedList class with the specified ordered marker.
        :param marker: The ordered marker to initialize the sorted list with.
        """
        ptrMarker: c_void_p = marker.Ptr
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListI.argtypes = [c_void_p]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListI.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListI(ptrMarker)
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, items: PdfListItemCollection, marker: PdfOrderedMarker):
        """
        Initializes a new instance of the PdfSortedList class with the specified item collection and ordered marker.
        :param items: The item collection to initialize the sorted list with.
        :param marker: The ordered marker to initialize the sorted list with.
        """
        ptrItem: c_void_p = items.Ptr
        ptrMarker: c_void_p = marker.Ptr
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListIM.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListIM.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListIM(ptrItem, ptrMarker)
        super(PdfSortedList, self).__init__(intPtr)

    @dispatch
    def __init__(self, text: str, marker: PdfOrderedMarker):
        """
        Initializes a new instance of the PdfSortedList class with the specified text and ordered marker.
        :param text: The text to initialize the sorted list with.
        :param marker: The ordered marker to initialize the sorted list with.
        """
        ptrMarker: c_void_p = marker.Ptr
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListTM.argtypes = [c_wchar_p, c_void_p]
        GetDllLibPdf().PdfSortedList_CreatePdfSortedListTM.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_CreatePdfSortedListTM(text, ptrMarker)
        super(PdfSortedList, self).__init__(intPtr)

    @property
    def Marker(self) -> 'PdfOrderedMarker':
        """
        Gets or sets the marker of the list items.
        """
        GetDllLibPdf().PdfSortedList_get_Marker.argtypes = [c_void_p]
        GetDllLibPdf().PdfSortedList_get_Marker.restype = c_void_p
        intPtr = GetDllLibPdf().PdfSortedList_get_Marker(self.Ptr)
        ret = None if intPtr == None else PdfOrderedMarker(intPtr)
        return ret

    @Marker.setter
    def Marker(self, value: 'PdfOrderedMarker'):
        """
        Sets the marker of the list items.
        :param value: The marker to set.
        """
        GetDllLibPdf().PdfSortedList_set_Marker.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfSortedList_set_Marker(self.Ptr, value.Ptr)

    @property
    def MarkerHierarchy(self) -> bool:
        """
        Gets or sets a value indicating whether to use numbering hierarchy.
        """
        GetDllLibPdf().PdfSortedList_get_MarkerHierarchy.argtypes = [c_void_p]
        GetDllLibPdf().PdfSortedList_get_MarkerHierarchy.restype = c_bool
        ret = GetDllLibPdf().PdfSortedList_get_MarkerHierarchy(self.Ptr)
        return ret

    @MarkerHierarchy.setter
    def MarkerHierarchy(self, value: bool):
        """
        Sets a value indicating whether to use numbering hierarchy.
        :param value: The value to set.
        """
        GetDllLibPdf().PdfSortedList_set_MarkerHierarchy.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfSortedList_set_MarkerHierarchy(self.Ptr, value)
