from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSound(SpireObject):
    """
    Represents sound embedded into pdf document.
    """

    @property
    def Rate(self) -> int:
        """
        Gets or sets the sampling rate, in samples per second (in Hz).
        """
        GetDllLibPdf().PdfSound_get_Rate.argtypes = [c_void_p]
        GetDllLibPdf().PdfSound_get_Rate.restype = c_int
        ret = GetDllLibPdf().PdfSound_get_Rate(self.Ptr)
        return ret

    @Rate.setter
    def Rate(self, value: int):
        """
        Sets the sampling rate, in samples per second (in Hz).
        """
        GetDllLibPdf().PdfSound_set_Rate.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSound_set_Rate(self.Ptr, value)

    @property
    def Bits(self) -> int:
        """
        Gets or sets the number of bits per sample value per channel.
        """
        GetDllLibPdf().PdfSound_get_Bits.argtypes = [c_void_p]
        GetDllLibPdf().PdfSound_get_Bits.restype = c_int
        ret = GetDllLibPdf().PdfSound_get_Bits(self.Ptr)
        return ret

    @Bits.setter
    def Bits(self, value: int):
        """
        Sets the number of bits per sample value per channel.
        """
        GetDllLibPdf().PdfSound_set_Bits.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSound_set_Bits(self.Ptr, value)

    @property
    def Encoding(self) -> 'PdfSoundEncoding':
        """
        Gets or sets the encoding format for the sample data.
        """
        GetDllLibPdf().PdfSound_get_Encoding.argtypes = [c_void_p]
        GetDllLibPdf().PdfSound_get_Encoding.restype = c_int
        ret = GetDllLibPdf().PdfSound_get_Encoding(self.Ptr)
        objwrapped = PdfSoundEncoding(ret)
        return objwrapped

    @Encoding.setter
    def Encoding(self, value: 'PdfSoundEncoding'):
        """
        Sets the encoding format for the sample data.
        """
        GetDllLibPdf().PdfSound_set_Encoding.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSound_set_Encoding(self.Ptr, value.value)

    @property
    def Channels(self) -> 'PdfSoundChannels':
        """
        Gets or sets the number of sound channels.
        """
        GetDllLibPdf().PdfSound_get_Channels.argtypes = [c_void_p]
        GetDllLibPdf().PdfSound_get_Channels.restype = c_int
        ret = GetDllLibPdf().PdfSound_get_Channels(self.Ptr)
        objwrapped = PdfSoundChannels(ret)
        return objwrapped

    @Channels.setter
    def Channels(self, value: 'PdfSoundChannels'):
        """
        Sets the number of sound channels.
        """
        GetDllLibPdf().PdfSound_set_Channels.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfSound_set_Channels(self.Ptr, value.value)

    @property
    def FileName(self) -> str:
        """
        Gets the name of the file.
        """
        GetDllLibPdf().PdfSound_get_FileName.argtypes = [c_void_p]
        GetDllLibPdf().PdfSound_get_FileName.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfSound_get_FileName(self.Ptr))
        return ret

    @FileName.setter
    def FileName(self, value: str):
        """
        Sets the name of the file.
        """
        GetDllLibPdf().PdfSound_set_FileName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfSound_set_FileName(self.Ptr, value)