from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfSquareAnnotationWidget(PdfMarkUpAnnotationWidget):
    """
    Represents a square annotation widget in a PDF document.
    """

    @property
    def RectangularDifferenceArray(self) -> List[float]:
        """
        Gets or sets the rectangular differences array of the square annotation widget.
        """
        GetDllLibPdf().PdfSquareAnnotationWidget_get_RectangularDifferenceArray.argtypes = [c_void_p]
        GetDllLibPdf().PdfSquareAnnotationWidget_get_RectangularDifferenceArray.restype = IntPtrArray
        intPtrArray = GetDllLibPdf().PdfSquareAnnotationWidget_get_RectangularDifferenceArray(self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @RectangularDifferenceArray.setter
    def RectangularDifferenceArray(self, value: List[float]):
        """
        Sets the rectangular differences array of the square annotation widget.
        """
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfSquareAnnotationWidget_set_RectangularDifferenceArray.argtypes = [c_void_p, ArrayType, c_int]
        GetDllLibPdf().PdfSquareAnnotationWidget_set_RectangularDifferenceArray(self.Ptr, vArray, vCount)

    def ObjectID(self) -> int:
        """
        Gets the object ID of the square annotation widget.
        """
        GetDllLibPdf().PdfSquareAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfSquareAnnotationWidget_ObjectID.restype = c_int
        ret = GetDllLibPdf().PdfSquareAnnotationWidget_ObjectID(self.Ptr)
        return ret