from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStructureTreeRoot(SpireObject):
    """
    PDF’s logical structure facilities provide a mechanism for incorporating
    structural information about a document’s content into a PDF file. Such
    information might include, for example, the organization of the document into
    chapters and sections or the identification of special elements such as figures,
    tables, and footnotes. The logical structure facilities are extensible, allowing
    applications that produce PDF files to choose what structural information to
    include and how to represent it, while enabling PDF consumers to navigate a file
    without knowing the producer’s structural conventions.
    """

    def AppendChildElement(self, structureType: str) -> 'PdfStructureElement':
        """
        Append structure type element.

        Args:
            structureType: The structure type.

        Returns:
            The pdf structure type element.
        """
        GetDllLibPdf().PdfStructureTreeRoot_AppendChildElement.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfStructureTreeRoot_AppendChildElement.restype = c_void_p
        intPtr = GetDllLibPdf().PdfStructureTreeRoot_AppendChildElement(self.Ptr, structureType)
        ret = None if intPtr == None else PdfStructureElement(intPtr)
        return ret


#
#    def GetChildElements(self)->'List1':
#        """
#    <summary>
#        Get the children structure elements.
#    </summary>
#    <returns>The pdf structure type element list.</returns>
#        """
#        GetDllLibPdf().PdfStructureTreeRoot_GetChildElements.argtypes=[c_void_p]
#        GetDllLibPdf().PdfStructureTreeRoot_GetChildElements.restype=c_void_p
#        intPtr = GetDllLibPdf().PdfStructureTreeRoot_GetChildElements(self.Ptr)
#        ret = None if intPtr==None else List1(intPtr)
#        return ret
#