from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTable (  PdfLayoutWidget) :
    @dispatch
    def __init__(self):
        GetDllLibPdf().PdfTable_CreatePdfTable.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTable_CreatePdfTable()
        super(PdfTable, self).__init__(intPtr)
    """
    Represents fast table with few features.
    """
    @property

    def Columns(self)->'PdfColumnCollection':
        """
        Gets the columns.
        """
        GetDllLibPdf().PdfTable_get_Columns.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_Columns.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_get_Columns(self.Ptr)
        ret = None if intPtr==None else PdfColumnCollection(intPtr)
        return ret


    @property

    def Rows(self)->'PdfRowCollection':
        """
        Gets the rows.
        """
        GetDllLibPdf().PdfTable_get_Rows.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_Rows.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_get_Rows(self.Ptr)
        ret = None if intPtr==None else PdfRowCollection(intPtr)
        return ret


    @property

    def DataSource(self)->'SpireObject':
        """
        Gets or sets the data source.
        """
        GetDllLibPdf().PdfTable_get_DataSource.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_DataSource.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_get_DataSource(self.Ptr)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    @DataSource.setter
    def DataSource(self, value:List[str]):
        countinputFiles = len(value)
        ArrayTypeinputFiles = c_wchar_p * countinputFiles
        arrayinputFiles = ArrayTypeinputFiles()
        for i in range(0, countinputFiles):
            arrayinputFiles[i] = value[i]

        GetDllLibPdf().PdfTable_set_DataSource.argtypes=[c_void_p, c_wchar_p, c_int]
        GetDllLibPdf().PdfTable_set_DataSource(self.Ptr, arrayinputFiles,countinputFiles)

    def SetDataSource(self, value:List[str]):
        countinputFiles = len(value)
        ArrayTypeinputFiles = c_wchar_p * countinputFiles
        arrayinputFiles = ArrayTypeinputFiles()
        for i in range(0, countinputFiles):
            arrayinputFiles[i] = value[i]

        GetDllLibPdf().PdfTable_set_DataSource.argtypes=[c_void_p, c_wchar_p, c_int]
        GetDllLibPdf().PdfTable_set_DataSource(self.Ptr, arrayinputFiles,countinputFiles)

    @property

    def DataMember(self)->str:
        """
        Gets or sets the data member.
        """
        GetDllLibPdf().PdfTable_get_DataMember.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_DataMember.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfTable_get_DataMember(self.Ptr))
        return ret


    @DataMember.setter
    def DataMember(self, value:str):
        GetDllLibPdf().PdfTable_set_DataMember.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfTable_set_DataMember(self.Ptr, value)

    @property

    def DataSourceType(self)->'PdfTableDataSourceType':
        """
        Gets or sets the datasource type of the PdfTable
        """
        GetDllLibPdf().PdfTable_get_DataSourceType.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_DataSourceType.restype=c_int
        ret = GetDllLibPdf().PdfTable_get_DataSourceType(self.Ptr)
        objwraped = PdfTableDataSourceType(ret)
        return objwraped

    @DataSourceType.setter
    def DataSourceType(self, value:'PdfTableDataSourceType'):
        GetDllLibPdf().PdfTable_set_DataSourceType.argtypes=[c_void_p, c_int]
        GetDllLibPdf().PdfTable_set_DataSourceType(self.Ptr, value.value)

    @property

    def Style(self)->'PdfTableStyle':
        """
        Gets or sets the properties.
        """
        GetDllLibPdf().PdfTable_get_Style.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_Style.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_get_Style(self.Ptr)
        ret = None if intPtr==None else PdfTableStyle(intPtr)
        return ret


    @Style.setter
    def Style(self, value:'PdfTableStyle'):
        GetDllLibPdf().PdfTable_set_Style.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfTable_set_Style(self.Ptr, value.Ptr)

    @property
    def IgnoreSorting(self)->bool:
        """
        Gets or sets a value indicating whether
            PdfTable should ignore sorting in data table.
        """
        GetDllLibPdf().PdfTable_get_IgnoreSorting.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_IgnoreSorting.restype=c_bool
        ret = GetDllLibPdf().PdfTable_get_IgnoreSorting(self.Ptr)
        return ret

    @IgnoreSorting.setter
    def IgnoreSorting(self, value:bool):
        GetDllLibPdf().PdfTable_set_IgnoreSorting.argtypes=[c_void_p, c_bool]
        GetDllLibPdf().PdfTable_set_IgnoreSorting(self.Ptr, value)

    @property
    def AllowCrossPages(self)->bool:
        """
        Gets a value Indicates whether can cross a page.
        """
        GetDllLibPdf().PdfTable_get_AllowCrossPages.argtypes=[c_void_p]
        GetDllLibPdf().PdfTable_get_AllowCrossPages.restype=c_bool
        ret = GetDllLibPdf().PdfTable_get_AllowCrossPages(self.Ptr)
        return ret

    @AllowCrossPages.setter
    def AllowCrossPages(self, value:bool):
        GetDllLibPdf().PdfTable_set_AllowCrossPages.argtypes=[c_void_p, c_bool]
        GetDllLibPdf().PdfTable_set_AllowCrossPages(self.Ptr, value)


    @dispatch

    def Draw(self ,graphics:'PdfCanvas',location:PointF,width:float):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
			location (PointF): The location of the element.
			width (float): The width of the table.
        """		
        intPtrgraphics:c_void_p = graphics.Ptr
        intPtrlocation:c_void_p = location.Ptr

        GetDllLibPdf().PdfTable_Draw.argtypes=[c_void_p ,c_void_p,c_void_p,c_float]
        GetDllLibPdf().PdfTable_Draw(self.Ptr, intPtrgraphics,intPtrlocation,width)

    @dispatch

    def Draw(self ,graphics:'PdfCanvas',x:float,y:float,width:float):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
			x (float): X co-ordinate of the element.
			y (float): Y co-ordinate of the element.
			width (float): The width of the table.
        """		
        intPtrgraphics:c_void_p = graphics.Ptr

        GetDllLibPdf().PdfTable_DrawGXYW.argtypes=[c_void_p ,c_void_p,c_float,c_float,c_float]
        GetDllLibPdf().PdfTable_DrawGXYW(self.Ptr, intPtrgraphics,x,y,width)

    @dispatch

    def Draw(self ,graphics:'PdfCanvas',bounds:RectangleF):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
			bounds (RectangleF): The bounds.
        """		
        intPtrgraphics:c_void_p = graphics.Ptr
        intPtrbounds:c_void_p = bounds.Ptr

        GetDllLibPdf().PdfTable_DrawGB.argtypes=[c_void_p ,c_void_p,c_void_p]
        GetDllLibPdf().PdfTable_DrawGB(self.Ptr, intPtrgraphics,intPtrbounds)

    @dispatch

    def Draw(self ,page:'PdfNewPage',location:PointF)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			location (PointF): The location.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """		
        intPtrpage:c_void_p = page.Ptr
        intPtrlocation:c_void_p = location.Ptr

        GetDllLibPdf().PdfTable_DrawPL.argtypes=[c_void_p ,c_void_p,c_void_p]
        GetDllLibPdf().PdfTable_DrawPL.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPL(self.Ptr, intPtrpage,intPtrlocation)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',location:PointF,format:PdfTableLayoutFormat)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			location (PointF): The location.
			format (PdfTableLayoutFormat): The format.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """		
        intPtrpage:c_void_p = page.Ptr
        intPtrlocation:c_void_p = location.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTable_DrawPLF.argtypes=[c_void_p ,c_void_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTable_DrawPLF.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPLF(self.Ptr, intPtrpage,intPtrlocation,intPtrformat)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',bounds:RectangleF)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			bounds (RectangleF): The location.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """			
        intPtrpage:c_void_p = page.Ptr
        intPtrbounds:c_void_p = bounds.Ptr

        GetDllLibPdf().PdfTable_DrawPB.argtypes=[c_void_p ,c_void_p,c_void_p]
        GetDllLibPdf().PdfTable_DrawPB.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPB(self.Ptr, intPtrpage,intPtrbounds)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',bounds:RectangleF,format:PdfTableLayoutFormat)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			bounds (RectangleF): The location.
			format (PdfTableLayoutFormat): The format.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """			
        intPtrpage:c_void_p = page.Ptr
        intPtrbounds:c_void_p = bounds.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTable_DrawPBF.argtypes=[c_void_p ,c_void_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTable_DrawPBF.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPBF(self.Ptr, intPtrpage,intPtrbounds,intPtrformat)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',x:float,y:float)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			x (float): The x coordinate.
			y (float): The y coordinate.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """		
        intPtrpage:c_void_p = page.Ptr

        GetDllLibPdf().PdfTable_DrawPXY.argtypes=[c_void_p ,c_void_p,c_float,c_float]
        GetDllLibPdf().PdfTable_DrawPXY.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPXY(self.Ptr, intPtrpage,x,y)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',x:float,y:float,format:PdfTableLayoutFormat)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			x (float): The x coordinate.
			y (float): The y coordinate.
			format (PdfTableLayoutFormat): The format.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """		
        intPtrpage:c_void_p = page.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTable_DrawPXYF.argtypes=[c_void_p ,c_void_p,c_float,c_float,c_void_p]
        GetDllLibPdf().PdfTable_DrawPXYF.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPXYF(self.Ptr, intPtrpage,x,y,intPtrformat)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',x:float,y:float,width:float)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			x (float): The x coordinate.
			y (float): The y coordinate.
			width (float): The width.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """			
        intPtrpage:c_void_p = page.Ptr

        GetDllLibPdf().PdfTable_DrawPXYW.argtypes=[c_void_p ,c_void_p,c_float,c_float,c_float]
        GetDllLibPdf().PdfTable_DrawPXYW.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPXYW(self.Ptr, intPtrpage,x,y,width)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page:'PdfNewPage',x:float,y:float,width:float,format:PdfTableLayoutFormat)->PdfTableLayoutResult:
        """
        Draws the table starting from the specified page.

        Args:
            page (PdfNewPage): The page.
			x (float): The x coordinate.
			y (float): The y coordinate.
			width (float): The width.
			format (PdfTableLayoutFormat): The format.
			
        Returns:
            PdfTableLayoutResult: The results of the lay outing.
        """		
        intPtrpage:c_void_p = page.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTable_DrawPXYWF.argtypes=[c_void_p ,c_void_p,c_float,c_float,c_float,c_void_p]
        GetDllLibPdf().PdfTable_DrawPXYWF.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTable_DrawPXYWF(self.Ptr, intPtrpage,x,y,width,intPtrformat)
        ret = None if intPtr==None else PdfTableLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,graphics:'PdfCanvas',x:float,y:float):
        """
        Draws an element on the Graphics.

        Args:
            graphics (PdfCanvas): Graphics context where the element should be printed.
			x (float): X co-ordinate of the element.
			y (float): Y co-ordinate of the element.
        """			
        intPtrgraphics:c_void_p = graphics.Ptr

        GetDllLibPdf().PdfTable_DrawGXY.argtypes=[c_void_p ,c_void_p,c_float,c_float]
        GetDllLibPdf().PdfTable_DrawGXY(self.Ptr, intPtrgraphics,x,y)

