from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTemplate(PdfShapeWidget):
    """
    Represents Pdf Template object.
    """

    @dispatch
    def __init__(self, size: SizeF):
        """
        Initializes a new instance of the PdfTemplate class with the specified size.
        :param size: The size of the template.
        """
        intPtrr: c_void_p = size.Ptr
        GetDllLibPdf().PdfTemplate_CreatePdfTemplateS.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_CreatePdfTemplateS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTemplate_CreatePdfTemplateS(intPtrr)
        super(PdfTemplate, self).__init__(intPtr)

    @dispatch
    def __init__(self, width: float, height: float):
        """
        Initializes a new instance of the PdfTemplate class with the specified width and height.
        :param width: The width of the template.
        :param height: The height of the template.
        """
        GetDllLibPdf().PdfTemplate_CreatePdfTemplateWH.argtypes = [c_float, c_float]
        GetDllLibPdf().PdfTemplate_CreatePdfTemplateWH.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTemplate_CreatePdfTemplateWH(width, height)
        super(PdfTemplate, self).__init__(intPtr)

    @dispatch
    def __init__(self, width: float, height: float, isPdfAppearance: bool):
        """
        Initializes a new instance of the PdfTemplate class with the specified width, height, and isPdfAppearance.
        :param width: The width of the template.
        :param height: The height of the template.
        :param isPdfAppearance: A boolean value indicating whether the template is a PDF appearance.
        """
        GetDllLibPdf().PdfTemplate_CreatePdfTemplateWHI.argtypes = [c_float, c_float, c_bool]
        GetDllLibPdf().PdfTemplate_CreatePdfTemplateWHI.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTemplate_CreatePdfTemplateWHI(width, height, isPdfAppearance)
        super(PdfTemplate, self).__init__(intPtr)

    @property
    def Graphics(self) -> 'PdfCanvas':
        """
        Gets the graphics context of the template.
        :return: The graphics context of the template. It will return None if the template is read-only.
        """
        GetDllLibPdf().PdfTemplate_get_Graphics.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_get_Graphics.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTemplate_get_Graphics(self.Ptr)
        ret = None if intPtr == None else PdfCanvas(intPtr)
        return ret

    @property
    def Size(self) -> 'SizeF':
        """
        Gets the size of the template.
        :return: The size of the template.
        """
        GetDllLibPdf().PdfTemplate_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_get_Size.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTemplate_get_Size(self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @property
    def Width(self) -> float:
        """
        Gets the width of the template.
        :return: The width of the template.
        """
        GetDllLibPdf().PdfTemplate_get_Width.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_get_Width.restype = c_float
        ret = GetDllLibPdf().PdfTemplate_get_Width(self.Ptr)
        return ret

    @property
    def Height(self) -> float:
        """
        Gets the height of the template.
        :return: The height of the template.
        """
        GetDllLibPdf().PdfTemplate_get_Height.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_get_Height.restype = c_float
        ret = GetDllLibPdf().PdfTemplate_get_Height(self.Ptr)
        return ret

    @property
    def ReadOnly(self) -> bool:
        """
        Gets a value indicating whether the template is read-only.
        :return: True if the template is read-only; otherwise, False.
        """
        GetDllLibPdf().PdfTemplate_get_ReadOnly.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_get_ReadOnly.restype = c_bool
        ret = GetDllLibPdf().PdfTemplate_get_ReadOnly(self.Ptr)
        return ret

    @dispatch
    def Reset(self, size: SizeF):
        """
        Resets the template and sets the specified size.
        :param size: The size to set.
        """
        intPtrsize: c_void_p = size.Ptr
        GetDllLibPdf().PdfTemplate_Reset.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfTemplate_Reset(self.Ptr, intPtrsize)

    @dispatch
    def Reset(self):
        """
        Resets an instance.
        """
        GetDllLibPdf().PdfTemplate_Reset1.argtypes = [c_void_p]
        GetDllLibPdf().PdfTemplate_Reset1(self.Ptr)