from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTextFragment(SpireObject):
    """
    The class representing a result of searching designated text from PDF page.
    """

    @property
    def Text(self) -> str:
        """
        Gets the text.
        """
        GetDllLibPdf().PdfTextFragment_get_Text.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Text.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfTextFragment_get_Text(self.Ptr))
        return ret

    @property
    def LineText(self) -> str:
        """
        Gets all text of the line which covers the target text.
        """
        GetDllLibPdf().PdfTextFragment_get_LineText.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_get_LineText.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfTextFragment_get_LineText(self.Ptr))
        return ret

    @property
    def Page(self) -> 'PdfPageBase':
        """
        Gets the page where the text is located.
        """
        GetDllLibPdf().PdfTextFragment_get_Page.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_get_Page.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextFragment_get_Page(self.Ptr)
        ret = None if intPtr == None else PdfPageBase(intPtr)
        return ret

    @dispatch
    def HighLight(self):
        """
        Highlight the target text.
        """
        GetDllLibPdf().PdfTextFragment_HighLight.argtypes = [c_void_p]
        GetDllLibPdf().PdfTextFragment_HighLight(self.Ptr)

    @dispatch
    def HighLight(self, color: Color):
        """
        Highlight the target text.
        :param name="color": The hight light color.
        """
        intPtrcolor: c_void_p = color.Ptr
        GetDllLibPdf().PdfTextFragment_HighLightC.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfTextFragment_HighLightC(self.Ptr, intPtrcolor)