from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTextWidget (  PdfLayoutWidget) :
    """
    Represents the text area with the ability to span several pages.
    """
    @dispatch
    def __init__(self):
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidget.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_CreatePdfTextWidget()
        super(PdfTextWidget, self).__init__(intPtr)

    @dispatch
    def __init__(self, text:str):
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetT.argtypes=[c_wchar_p]
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetT.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetT(text)
        super(PdfTextWidget, self).__init__(intPtr)

    @dispatch
    def __init__(self, text:str,font:PdfFontBase):
        ptrfont:c_void_p = font.Ptr
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTF.argtypes=[c_wchar_p,c_void_p]
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTF(text,ptrfont)
        super(PdfTextWidget, self).__init__(intPtr)

    @dispatch
    def __init__(self, text:str,font:PdfFontBase,pen:PdfPen):
        ptrfont:c_void_p = font.Ptr
        ptrpen:c_void_p = pen.Ptr
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFP.argtypes=[c_wchar_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFP(text,ptrfont,ptrpen)
        super(PdfTextWidget, self).__init__(intPtr)

    @dispatch
    def __init__(self, text:str,font:PdfFontBase,brush:PdfBrush):
        ptrfont:c_void_p = font.Ptr
        ptrbrush:c_void_p = brush.Ptr
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFB.argtypes=[c_wchar_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFB.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFB(text,ptrfont,ptrbrush)
        super(PdfTextWidget, self).__init__(intPtr)

    @dispatch
    def __init__(self, text:str,font:PdfFontBase,pen:PdfPen,brush:PdfBrush,format:PdfStringFormat):
        ptrfont:c_void_p = font.Ptr
        ptrpen:c_void_p = pen.Ptr
        ptrbrush:c_void_p = brush.Ptr
        ptrformat:c_void_p = format.Ptr
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFPBF.argtypes=[c_wchar_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFPBF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_CreatePdfTextWidgetTFPBF(text,ptrfont,ptrpen,ptrbrush,ptrformat)
        super(PdfTextWidget, self).__init__(intPtr)

    @property

    def Text(self)->str:
        """
        Gets or sets a value indicating the text that should be printed.
        """
        GetDllLibPdf().PdfTextWidget_get_Text.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextWidget_get_Text.restype=c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfTextWidget_get_Text(self.Ptr))
        return ret


    @Text.setter
    def Text(self, value:str):
        GetDllLibPdf().PdfTextWidget_set_Text.argtypes=[c_void_p, c_wchar_p]
        GetDllLibPdf().PdfTextWidget_set_Text(self.Ptr, value)

    @property

    def Pen(self)->'PdfPen':
        """
        Gets or sets a pen that will be used to draw the text.
        """
        GetDllLibPdf().PdfTextWidget_get_Pen.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextWidget_get_Pen.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_get_Pen(self.Ptr)
        ret = None if intPtr==None else PdfPen(intPtr)
        return ret


    @Pen.setter
    def Pen(self, value:'PdfPen'):
        GetDllLibPdf().PdfTextWidget_set_Pen.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfTextWidget_set_Pen(self.Ptr, value.Ptr)

    @property

    def Brush(self)->'PdfBrush':
        """
        Gets or sets the brush that will be used to draw the text.
        """
        GetDllLibPdf().PdfTextWidget_get_Brush.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextWidget_get_Brush.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_get_Brush(self.Ptr)
        ret = None if intPtr==None else PdfBrush(intPtr)
        return ret


    @Brush.setter
    def Brush(self, value:'PdfBrush'):
        GetDllLibPdf().PdfTextWidget_set_Brush.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfTextWidget_set_Brush(self.Ptr, value.Ptr)

    @property

    def Font(self)->'PdfFontBase':
        """
        Gets or sets a font that will be used to draw the text.
        """
        GetDllLibPdf().PdfTextWidget_get_Font.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextWidget_get_Font.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_get_Font(self.Ptr)
        ret = None if intPtr==None else PdfFontBase(intPtr)
        return ret


    @Font.setter
    def Font(self, value:'PdfFontBase'):
        GetDllLibPdf().PdfTextWidget_set_Font.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfTextWidget_set_Font(self.Ptr, value.Ptr)

    @property

    def StringFormat(self)->'PdfStringFormat':
        """
        Gets or sets text settings that will be used to draw the text.
        """
        GetDllLibPdf().PdfTextWidget_get_StringFormat.argtypes=[c_void_p]
        GetDllLibPdf().PdfTextWidget_get_StringFormat.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_get_StringFormat(self.Ptr)
        ret = None if intPtr==None else PdfStringFormat(intPtr)
        return ret


    @StringFormat.setter
    def StringFormat(self, value:'PdfStringFormat'):
        GetDllLibPdf().PdfTextWidget_set_StringFormat.argtypes=[c_void_p, c_void_p]
        GetDllLibPdf().PdfTextWidget_set_StringFormat(self.Ptr, value.Ptr)

    @dispatch

    def Draw(self ,page,location:PointF,format:PdfTextLayout)->PdfTextLayoutResult:
        """
        Draws the text on the page.

        Args:
            page (PdfPageBase): Current page where the text should be drawn.
			location (PointF): Start location on the page.
			format (PdfTextLayout): Lay outing format.

        Returns:
            PdfTextLayoutResult: Lay outing result.
        """		
        intPtrpage:c_void_p = page.Ptr
        intPtrlocation:c_void_p = location.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTextWidget_Draw.argtypes=[c_void_p ,c_void_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTextWidget_Draw.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_Draw(self.Ptr, intPtrpage,intPtrlocation,intPtrformat)
        ret = None if intPtr==None else PdfTextLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page,location:PointF,width:float,format:PdfTextLayout)->PdfTextLayoutResult:
        """
        Draws the text on the page.

        Args:
            page (PdfPageBase): Current page where the text should be drawn.
			location (PointF): Start location on the page.
			width (float): Width of the text bounds.
			format (PdfTextLayout): Lay outing format.

        Returns:
            PdfTextLayoutResult: Lay outing result.
        """			
        intPtrpage:c_void_p = page.Ptr
        intPtrlocation:c_void_p = location.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTextWidget_DrawPLWF.argtypes=[c_void_p ,c_void_p,c_void_p,c_float,c_void_p]
        GetDllLibPdf().PdfTextWidget_DrawPLWF.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_DrawPLWF(self.Ptr, intPtrpage,intPtrlocation,width,intPtrformat)
        ret = None if intPtr==None else PdfTextLayoutResult(intPtr)
        return ret


    @dispatch

    def Draw(self ,page,layoutRectangle:RectangleF,format:PdfTextLayout)->PdfTextLayoutResult:
        """
        Draws the text on the page.

        Args:
            page (PdfPageBase): Current page where the text should be drawn.
			layoutRectangle (RectangleF): RectangleF structure that specifies the bounds of the text.
			format (PdfTextLayout): Lay outing format.

        Returns:
            PdfTextLayoutResult: Lay outing result.
        """		
        intPtrpage:c_void_p = page.Ptr
        intPtrlayoutRectangle:c_void_p = layoutRectangle.Ptr
        intPtrformat:c_void_p = format.Ptr

        GetDllLibPdf().PdfTextWidget_DrawPLF.argtypes=[c_void_p ,c_void_p,c_void_p,c_void_p]
        GetDllLibPdf().PdfTextWidget_DrawPLF.restype=c_void_p
        intPtr = GetDllLibPdf().PdfTextWidget_DrawPLF(self.Ptr, intPtrpage,intPtrlayoutRectangle,intPtrformat)
        ret = None if intPtr==None else PdfTextLayoutResult(intPtr)
        return ret


