from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfTilingBrush(PdfBrush):
    """
    Implements a colored tiling brush.
    """

    @dispatch
    def __init__(self, rectangle: RectangleF):
        """
        Initializes a new instance of the PdfTilingBrush class with the specified rectangle.
        """
        ptrRec: c_void_p = rectangle.Ptr
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushR.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushR.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushR(ptrRec)
        super(PdfTilingBrush, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF, page):
        """
        Initializes a new instance of the PdfTilingBrush class with the specified rectangle and page.
        """
        ptrRec: c_void_p = rectangle.Ptr
        ptrPage: c_void_p = page.Ptr
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushRP.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushRP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushRP(ptrRec, ptrPage)
        super(PdfTilingBrush, self).__init__(intPtr)

    @dispatch
    def __init__(self, size: SizeF):
        """
        Initializes a new instance of the PdfTilingBrush class with the specified size.
        """
        ptrSize: c_void_p = size.Ptr
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushS.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushS(ptrSize)
        super(PdfTilingBrush, self).__init__(intPtr)

    @dispatch
    def __init__(self, size: SizeF, page):
        """
        Initializes a new instance of the PdfTilingBrush class with the specified size and page.
        """
        ptrSize: c_void_p = size.Ptr
        ptrPage: c_void_p = page.Ptr
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushSP.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushSP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_CreatePdfTilingBrushSP(ptrSize, ptrPage)
        super(PdfTilingBrush, self).__init__(intPtr)

    @property
    def Rectangle(self) -> 'RectangleF':
        """
        Gets the boundary box of the smallest brush cell.
        """
        GetDllLibPdf().PdfTilingBrush_get_Rectangle.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_get_Rectangle.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_get_Rectangle(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @property
    def Size(self) -> 'SizeF':
        """
        Gets the size of the smallest brush cell.
        """
        GetDllLibPdf().PdfTilingBrush_get_Size.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_get_Size.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_get_Size(self.Ptr)
        ret = None if intPtr == None else SizeF(intPtr)
        return ret

    @property
    def Graphics(self) -> 'PdfCanvas':
        """
        Gets the Graphics context of the brush.
        """
        GetDllLibPdf().PdfTilingBrush_get_Graphics.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_get_Graphics.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_get_Graphics(self.Ptr)
        ret = None if intPtr == None else PdfCanvas(intPtr)
        return ret

    def Clone(self) -> 'PdfBrush':
        """
        Creates a new copy of the brush.
        Returns:
            A new instance of the Brush class.
        """
        GetDllLibPdf().PdfTilingBrush_Clone.argtypes = [c_void_p]
        GetDllLibPdf().PdfTilingBrush_Clone.restype = c_void_p
        intPtr = GetDllLibPdf().PdfTilingBrush_Clone(self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret