from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfToLinearizedPdfConverter(SpireObject):
    @dispatch
    def __init__(self, filePath: str):
        """
        Initializes a new instance of the PdfToLinearizedPdfConverter class with the specified file path.

        Args:
            filePath: The file path of the PDF document.
        """
        GetDllLibPdf().PdfToLinearizedPdfConverter_CreatePdfToLinearizedPdfConverterF.argtypes = [c_wchar_p]
        GetDllLibPdf().PdfToLinearizedPdfConverter_CreatePdfToLinearizedPdfConverterF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfToLinearizedPdfConverter_CreatePdfToLinearizedPdfConverterF(filePath)
        super(PdfToLinearizedPdfConverter, self).__init__(intPtr)

    @dispatch
    def __init__(self, stream: Stream):
        """
        Initializes a new instance of the PdfToLinearizedPdfConverter class with the specified stream.

        Args:
            stream: The stream of the PDF document.
        """
        ptrStream: c_void_p = stream.Ptr
        GetDllLibPdf().PdfToLinearizedPdfConverter_CreatePdfToLinearizedPdfConverterS.argtypes = [c_void_p]
        GetDllLibPdf().PdfToLinearizedPdfConverter_CreatePdfToLinearizedPdfConverterS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfToLinearizedPdfConverter_CreatePdfToLinearizedPdfConverterS(ptrStream)
        super(PdfToLinearizedPdfConverter, self).__init__(intPtr)

    def ToLinearizedPdf(self, filePath: str):
        """
        Convert the PDF document to a linearized PDF document and save it to the specified file path.

        Args:
            filePath: The output file path.
        """
        GetDllLibPdf().PdfToLinearizedPdfConverter_ToLinearizedPdf.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfToLinearizedPdfConverter_ToLinearizedPdf(self.Ptr, filePath)

    def ToLinearizedPdf(self, stream: Stream):
        """
        Convert the PDF document to a linearized PDF document and save it to the specified stream.

        Args:
            stream: The output stream.
        """
        intPtrstream: c_void_p = stream.Ptr

        GetDllLibPdf().PdfToLinearizedPdfConverter_ToLinearizedPdfS.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfToLinearizedPdfConverter_ToLinearizedPdfS(self.Ptr, intPtrstream)

    def Dispose(self):
        """
        Dispose the PdfToLinearizedPdfConverter object.
        """
        GetDllLibPdf().PdfToLinearizedPdfConverter_Dispose.argtypes = [c_void_p]
        GetDllLibPdf().PdfToLinearizedPdfConverter_Dispose(self.Ptr)