from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfUriAnnotation(PdfActionLinkAnnotation):
    """
    Represents the Uri annotation.
    """
    @dispatch
    def __init__(self, rectangle: RectangleF):
        """
        Initializes a new instance of the PdfUriAnnotation class with the specified rectangle.
        """
        ptrrectangle: c_void_p = rectangle.Ptr

        GetDllLibPdf().PdfUriAnnotation_CreatePdfUriAnnotationR.argtypes = [c_void_p]
        GetDllLibPdf().PdfUriAnnotation_CreatePdfUriAnnotationR.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUriAnnotation_CreatePdfUriAnnotationR(ptrrectangle)
        super(PdfUriAnnotation, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF, uri: str):
        """
        Initializes a new instance of the PdfUriAnnotation class with the specified rectangle and URI.
        """
        ptrrectangle: c_void_p = rectangle.Ptr

        GetDllLibPdf().PdfUriAnnotation_CreatePdfUriAnnotationRU.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfUriAnnotation_CreatePdfUriAnnotationRU.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUriAnnotation_CreatePdfUriAnnotationRU(ptrrectangle, uri)
        super(PdfUriAnnotation, self).__init__(intPtr)

    @property
    def Uri(self) -> str:
        """
        Gets or sets the URI address.
        """
        GetDllLibPdf().PdfUriAnnotation_get_Uri.argtypes = [c_void_p]
        GetDllLibPdf().PdfUriAnnotation_get_Uri.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfUriAnnotation_get_Uri(self.Ptr))
        return ret

    @Uri.setter
    def Uri(self, value: str):
        """
        Sets the URI address.
        """
        GetDllLibPdf().PdfUriAnnotation_set_Uri.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfUriAnnotation_set_Uri(self.Ptr, value)

    @property
    def Action(self) -> 'PdfAction':
        """
        Gets or sets the action.
        """
        GetDllLibPdf().PdfUriAnnotation_get_Action.argtypes = [c_void_p]
        GetDllLibPdf().PdfUriAnnotation_get_Action.restype = c_void_p
        intPtr = GetDllLibPdf().PdfUriAnnotation_get_Action(self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @Action.setter
    def Action(self, value: 'PdfAction'):
        """
        Sets the action.
        """
        GetDllLibPdf().PdfUriAnnotation_set_Action.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfUriAnnotation_set_Action(self.Ptr, value.Ptr)
