from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfViewerPreferences(SpireObject):
    """
    Defines the way the document is to be presented on the screen or in print.
    """

    @property
    def CenterWindow(self) -> bool:
        """
        A flag specifying whether to position the documents window in the center of the screen.
        """
        GetDllLibPdf().PdfViewerPreferences_get_CenterWindow.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_CenterWindow.restype = c_bool
        ret = GetDllLibPdf().PdfViewerPreferences_get_CenterWindow(self.Ptr)
        return ret

    @CenterWindow.setter
    def CenterWindow(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_CenterWindow.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_CenterWindow(self.Ptr, value)

    @property
    def BookMarkExpandOrCollapse(self) -> bool:
        """
        A flag specifying whether to expand or collapse the bookmarks in the viewer application.
        """
        return True

    @BookMarkExpandOrCollapse.setter
    def BookMarkExpandOrCollapse(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_BookMarkExpandOrCollapse.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_BookMarkExpandOrCollapse(self.Ptr, value)

    @property
    def DisplayTitle(self) -> bool:
        """
        A flag specifying whether the window's title bar should display the document title taken from the Title entry of the document information dictionary. If false, the title bar should instead display the name of the PDF file containing the document.
        """
        GetDllLibPdf().PdfViewerPreferences_get_DisplayTitle.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_DisplayTitle.restype = c_bool
        ret = GetDllLibPdf().PdfViewerPreferences_get_DisplayTitle(self.Ptr)
        return ret

    @DisplayTitle.setter
    def DisplayTitle(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_DisplayTitle.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_DisplayTitle(self.Ptr, value)

    @property
    def FitWindow(self) -> bool:
        """
        A flag specifying whether to resize the document's window to fit the size of the first displayed page.
        """
        GetDllLibPdf().PdfViewerPreferences_get_FitWindow.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_FitWindow.restype = c_bool
        ret = GetDllLibPdf().PdfViewerPreferences_get_FitWindow(self.Ptr)
        return ret

    @FitWindow.setter
    def FitWindow(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_FitWindow.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_FitWindow(self.Ptr, value)

    @property
    def HideMenubar(self) -> bool:
        """
        A flag specifying whether to hide the viewer application's menu bar when the document is active.
        """
        GetDllLibPdf().PdfViewerPreferences_get_HideMenubar.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_HideMenubar.restype = c_bool
        ret = GetDllLibPdf().PdfViewerPreferences_get_HideMenubar(self.Ptr)
        return ret

    @HideMenubar.setter
    def HideMenubar(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_HideMenubar.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_HideMenubar(self.Ptr, value)

    @property
    def HideToolbar(self) -> bool:
        """
        A flag specifying whether to hide the viewer application's toolbars when the document is active.
        """
        GetDllLibPdf().PdfViewerPreferences_get_HideToolbar.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_HideToolbar.restype = c_bool
        ret = GetDllLibPdf().PdfViewerPreferences_get_HideToolbar(self.Ptr)
        return ret

    @HideToolbar.setter
    def HideToolbar(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_HideToolbar.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_HideToolbar(self.Ptr, value)

    @property
    def HideWindowUI(self) -> bool:
        """
        A flag specifying whether to hide user interface elements in the document's window (such as scroll bars and navigation controls), leaving only the document's contents displayed.
        """
        GetDllLibPdf().PdfViewerPreferences_get_HideWindowUI.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_HideWindowUI.restype = c_bool
        ret = GetDllLibPdf().PdfViewerPreferences_get_HideWindowUI(self.Ptr)
        return ret

    @HideWindowUI.setter
    def HideWindowUI(self, value: bool):
        GetDllLibPdf().PdfViewerPreferences_set_HideWindowUI.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfViewerPreferences_set_HideWindowUI(self.Ptr, value)

    @property
    def PageMode(self) -> 'PdfPageMode':
        """
        A name object specifying how the document should be displayed when opened.
        """
        GetDllLibPdf().PdfViewerPreferences_get_PageMode.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_PageMode.restype = c_int
        ret = GetDllLibPdf().PdfViewerPreferences_get_PageMode(self.Ptr)
        objwrapped = PdfPageMode(ret)
        return objwrapped

    @PageMode.setter
    def PageMode(self, value: 'PdfPageMode'):
        GetDllLibPdf().PdfViewerPreferences_set_PageMode.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfViewerPreferences_set_PageMode(self.Ptr, value.value)

    @property
    def PageLayout(self) -> 'PdfPageLayout':
        """
        A name object specifying the page layout to be used when the document is opened.
        """
        GetDllLibPdf().PdfViewerPreferences_get_PageLayout.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_PageLayout.restype = c_int
        ret = GetDllLibPdf().PdfViewerPreferences_get_PageLayout(self.Ptr)
        objwrapped = PdfPageLayout(ret)
        return objwrapped

    @PageLayout.setter
    def PageLayout(self, value: 'PdfPageLayout'):
        GetDllLibPdf().PdfViewerPreferences_set_PageLayout.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfViewerPreferences_set_PageLayout(self.Ptr, value.value)

    @property
    def PrintScaling(self) -> 'PrintScalingMode':
        """
        Gets or sets the page scaling option to be selected when a print dialog is displayed for this document.
        """
        GetDllLibPdf().PdfViewerPreferences_get_PrintScaling.argtypes = [c_void_p]
        GetDllLibPdf().PdfViewerPreferences_get_PrintScaling.restype = c_int
        ret = GetDllLibPdf().PdfViewerPreferences_get_PrintScaling(self.Ptr)
        objwrapped = PrintScalingMode(ret)
        return objwrapped

    @PrintScaling.setter
    def PrintScaling(self, value: 'PrintScalingMode'):
        GetDllLibPdf().PdfViewerPreferences_set_PrintScaling.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfViewerPreferences_set_PrintScaling(self.Ptr, value.value)