from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc


class XFAForm(SpireObject):
    """
    Represents XML Forms Architecture (XFA).
    """

    def get_Item(self, XmlPath: str) -> str:
        """
        Gets or sets data node value. Deprecated to use, instead use xfaField to set field value.
        """
        GetDllLibPdf().XFAForm_get_Item.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().XFAForm_get_Item.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().XFAForm_get_Item(self.Ptr, XmlPath))
        return ret

    def set_Item(self, XmlPath: str, value: str):
        """
        Sets data node value. Deprecated to use, instead use xfaField to set field value.
        """
        GetDllLibPdf().XFAForm_set_Item.argtypes = [c_void_p, c_wchar_p, c_wchar_p]
        GetDllLibPdf().XFAForm_set_Item(self.Ptr, XmlPath, value)

    @property
    def Count(self) -> int:
        """
        Returns the count.
        """
        GetDllLibPdf().XFAForm_get_Count.argtypes = [c_void_p]
        GetDllLibPdf().XFAForm_get_Count.restype = c_int
        ret = GetDllLibPdf().XFAForm_get_Count(self.Ptr)
        return ret

    def CheckFieldExists(self, fieldName: str) -> bool:
        """
        Checks if the field exists.
        """
        GetDllLibPdf().XFAForm_CheckFieldExists.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().XFAForm_CheckFieldExists.restype = c_bool
        ret = GetDllLibPdf().XFAForm_CheckFieldExists(self.Ptr, fieldName)
        return ret

    def getField(self, name: str) -> 'XfaField':
        """
        Added by Henry Zhou. 
        To get the xfaField through its name. Notes: the param 'name' is the name have been modified by codes instead of originals.
        """
        GetDllLibPdf().XFAForm_getField.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().XFAForm_getField.restype = c_void_p
        intPtr = GetDllLibPdf().XFAForm_getField(self.Ptr, name)
        ret = None if intPtr == None else XfaField(intPtr)
        return ret

    @staticmethod
    def FieldNameEscape() -> int:
        """
        Returns the field name escape.
        """
        GetDllLibPdf().XFAForm_FieldNameEscape.restype = c_int
        ret = GetDllLibPdf().XFAForm_FieldNameEscape()
        return ret