from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class XfaDateTimeField(XfaField):
    """
    Represents a XFA date/time field.
    """

    @property
    def Value(self) -> str:
        """
        Gets the value of the XFA date/time field.
        :return: The value of the XFA date/time field.
        """
        GetDllLibPdf().XfaDateTimeField_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().XfaDateTimeField_get_Value.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().XfaDateTimeField_get_Value(self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the XFA date/time field.
        :param value: The value to set.
        """
        GetDllLibPdf().XfaDateTimeField_set_Value.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().XfaDateTimeField_set_Value(self.Ptr, value)

    @property
    def DateTimeFormats(self) -> str:
        """
        Gets the date/time formats of the XFA date/time field.
        :return: The date/time formats of the XFA date/time field.
        """
        GetDllLibPdf().XfaDateTimeField_get_DateTimeFormats.argtypes = [c_void_p]
        GetDllLibPdf().XfaDateTimeField_get_DateTimeFormats.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().XfaDateTimeField_get_DateTimeFormats(self.Ptr))
        return ret